"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QPushButton(QAbstractButton):
    """
    https://doc.qt.io/qt-6/qpushbutton.html

    **Detailed Description**

    ![](images/windows-pushbutton.png)

    The push button, or command button, is perhaps the most commonly used widget
    in any graphical user interface. Push (click) a button to command the
    computer to perform some action, or to answer a question. Typical buttons
    are OK, Apply, Cancel, Close, Yes, No and Help.

    A command button is rectangular and typically displays a text label
    describing its action. A shortcut key can be specified by preceding the
    preferred character with an ampersand in the text. For example:

    **QPushButton**  *button = new **QPushButton** ("&Download", this);

    In this example the shortcut is **Alt+D**. See the **QShortcut**
    documentation for details (to display an actual ampersand, use '&&').

    Push buttons display a textual label, and optionally a small icon. These can
    be set using the constructors and changed later using **setText** () and
    **setIcon** (). If the button is disabled, the appearance of the text and
    icon will be manipulated with respect to the GUI style to make the button
    look "disabled".

    A push button emits the signal **clicked** () when it is activated by the
    mouse, the Spacebar or by a keyboard shortcut. Connect to this signal to
    perform the button's action. Push buttons also provide less commonly used
    signals, for example **pressed** () and **released** ().

    Command buttons in dialogs are by default auto-default buttons, i.e., they
    become the default push button automatically when they receive the keyboard
    input focus. A default button is a push button that is activated when the
    user presses the Enter or Return key in a dialog. You can change this with
    **setAutoDefault** (). Note that auto-default buttons reserve a little extra
    space which is necessary to draw a default-button indicator. If you do not
    want this space around your buttons, call **setAutoDefault** (false).

    Being so central, the button widget has grown to accommodate a great many
    variations in the past decade. The Microsoft style guide now shows about ten
    different states of Windows push buttons and the text implies that there are
    dozens more when all the combinations of features are taken into
    consideration.

    The most important modes or states are:

    * Available or not (grayed out, disabled).
      * Standard push button,
    toggling push button or menu button.
      * On or off (only for toggling push
    buttons).
      * Default or normal. The default button in a dialog can
    generally be "clicked" using the Enter or Return key.
      * Auto-repeat or
    not.
      * Pressed down or not.

    As a general rule, use a push button when the application or dialog window
    performs an action when the user clicks on it (such as Apply, Cancel, Close
    and Help) **and** when the widget is supposed to have a wide, rectangular
    shape with a text label. Small, typically square buttons that change the
    state of the window rather than performing an action (such as the buttons in
    the top-right corner of the **QFileDialog** ) are not command buttons, but
    tool buttons. Qt provides a special class (**QToolButton** ) for these
    buttons.

    If you need toggle behavior (see **setCheckable** ()) or a button that auto-
    repeats the activation signal when being pushed down like the arrows in a
    scroll bar (see **setAutoRepeat** ()), a command button is probably not what
    you want. When in doubt, use a tool button.

    **Note:** On macOS when a push button's width becomes smaller than 50 or its
    height becomes smaller than 30, the button's corners are changed from round
    to square. Use the **setMinimumSize** () function to prevent this behavior.

    A variation of a command button is a menu button. These provide not just one
    command, but several, since when they are clicked they pop up a menu of
    options. Use the method **setMenu** () to associate a popup menu with a push
    button.

    Other classes of buttons are option buttons (see **QRadioButton** ) and
    check boxes (see **QCheckBox** ).

    In Qt, the **QAbstractButton**  base class provides most of the modes and
    other API, and QPushButton provides GUI logic. See **QAbstractButton**  for
    more information about the API.

    **See also** **QToolButton** , **QRadioButton** , **QCheckBox** , and **GUI
    Design Handbook: Push Button** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#QPushButton

        **QPushButton::QPushButton(QWidget * parent = nullptr)**

        Constructs a push button with no text and a **parent**.
        """
        ...

    @typing.overload
    def __init__(self, text: str, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#QPushButton-1

        **QPushButton::QPushButton(const QString & text , QWidget * parent =
        nullptr)**

        Constructs a push button with the parent **parent** and the text
        **text**.
        """
        ...

    @typing.overload
    def __init__(
        self, icon: QtGui.QIcon, text: str, parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#QPushButton-2

        **QPushButton::QPushButton(const QIcon & icon , const QString & text ,
        QWidget * parent = nullptr)**

        Constructs a push button with an **icon** and a **text** , and a
        **parent**.

        Note that you can also pass a **QPixmap**  object as an icon (thanks to
        the implicit type conversion provided by C++).
        """
        ...

    def mouseMoveEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#mouseMoveEvent

        **[override virtual protected] void
        QPushButton::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QAbstractButton::mouseMoveEvent** (QMouseEvent *e).
        """
        ...

    def hitButton(self, pos: QtCore.QPoint) -> bool:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#hitButton

        **[override virtual protected] bool QPushButton::hitButton(const QPoint
        & pos ) const**

        Reimplements: **QAbstractButton::hitButton(const QPoint &pos) const** .
        """
        ...

    def focusOutEvent(self, a0: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#focusOutEvent

        **[override virtual protected] void
        QPushButton::focusOutEvent(QFocusEvent * e )**

        Reimplements: **QAbstractButton::focusOutEvent** (QFocusEvent *e).
        """
        ...

    def focusInEvent(self, a0: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#focusInEvent

        **[override virtual protected] void
        QPushButton::focusInEvent(QFocusEvent * e )**

        Reimplements: **QAbstractButton::focusInEvent** (QFocusEvent *e).
        """
        ...

    def keyPressEvent(self, a0: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#keyPressEvent

        **[override virtual protected] void QPushButton::keyPressEvent(QKeyEvent
        * e )**

        Reimplements: **QAbstractButton::keyPressEvent** (QKeyEvent *e).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#paintEvent

        **[override virtual protected] void QPushButton::paintEvent(QPaintEvent
        *)**

        Reimplements: **QAbstractButton::paintEvent** (QPaintEvent *e).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#event

        **[override virtual protected] bool QPushButton::event(QEvent * e )**

        Reimplements: **QAbstractButton::event** (QEvent *e).
        """
        ...

    def initStyleOption(self, option: "QStyleOptionButton") -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#initStyleOption

        **[virtual protected] void
        QPushButton::initStyleOption(QStyleOptionButton * option ) const**

        Initialize **option** with the values from this **QPushButton** . This
        method is useful for subclasses when they need a **QStyleOptionButton**
        , but don't want to fill in all the information themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def showMenu(self) -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#showMenu

        **[slot] void QPushButton::showMenu()**

        Shows (pops up) the associated popup menu. If there is no such menu,
        this function does nothing. This function does not return until the
        popup menu has been closed by the user.
        """
        ...

    def isFlat(self) -> bool:
        ...

    def setFlat(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#flat-prop

        **flat : bool**

        This property holds whether the button border is raised

        This property's default is false. If this property is set, most styles
        will not paint the button background unless the button is being pressed.
        **setAutoFillBackground** () can be used to ensure that the background
        is filled using the **QPalette::Button**  brush.

        **Access functions:**

        bool **isFlat** () const
        void **setFlat** (bool)

        **Member Function Documentation**
        """
        ...

    def menu(self) -> "QMenu":
        """
        https://doc.qt.io/qt-6/qpushbutton.html#menu

        **QMenu *QPushButton::menu() const**

        Returns the button's associated popup menu or `nullptr` if no popup menu
        has been set.

        **See also** **setMenu** ().
        """
        ...

    def setMenu(self, menu: "QMenu") -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#setMenu

        **void QPushButton::setMenu(QMenu * menu )**

        Associates the popup menu **menu** with this push button. This turns the
        button into a menu button, which in some styles will produce a small
        triangle to the right of the button's text.

        Ownership of the menu is **not** transferred to the push button.

        ![Screenshot of a Fusion style push button with popup
        menu.](images/fusion-pushbutton-menu.png)

        A push button with popup menus shown in the **Fusion widget style** .

        **See also** **menu** ().
        """
        ...

    def setDefault(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#default-prop

        **default : bool**

        This property holds whether the push button is the default button

        Default and autodefault buttons decide what happens when the user
        presses enter in a dialog.

        A button with this property set to true (i.e., the dialog's **default**
        button,) will automatically be pressed when the user presses enter, with
        one exception: if an **autoDefault** button currently has focus, the
        **autoDefault**  button is pressed. When the dialog has **autoDefault**
        buttons but no default button, pressing enter will press either the
        **autoDefault**  button that currently has focus, or if no button has
        focus, the next **autoDefault**  button in the focus chain.

        In a dialog, only one push button at a time can be the default button.
        This button is then displayed with an additional frame (depending on the
        GUI style).

        The default button behavior is provided only in dialogs. Buttons can
        always be clicked from the keyboard by pressing Spacebar when the button
        has focus.

        If the default property is set to false on the current default button
        while the dialog is visible, a new default will automatically be
        assigned the next time a push button in the dialog receives focus.

        This property's default is false.

        **Access functions:**

        bool **isDefault** () const
        void **setDefault** (bool)
        """
        ...

    def isDefault(self) -> bool:
        ...

    def setAutoDefault(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#autoDefault-prop

        **autoDefault : bool**

        This property holds whether the push button is an auto default button

        If this property is set to true then the push button is an auto default
        button.

        In some GUI styles a default button is drawn with an extra frame around
        it, up to 3 pixels or more. Qt automatically keeps this space free
        around auto-default buttons, i.e., auto-default buttons may have a
        slightly larger size hint.

        This property's default is true for buttons that have a **QDialog**
        parent; otherwise it defaults to false.

        See the **default**  property for details of how **default**  and auto-
        default interact.

        **Access functions:**

        bool **autoDefault** () const
        void **setAutoDefault** (bool)
        """
        ...

    def autoDefault(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#autoDefault-prop

        **autoDefault : bool**

        This property holds whether the push button is an auto default button

        If this property is set to true then the push button is an auto default
        button.

        In some GUI styles a default button is drawn with an extra frame around
        it, up to 3 pixels or more. Qt automatically keeps this space free
        around auto-default buttons, i.e., auto-default buttons may have a
        slightly larger size hint.

        This property's default is true for buttons that have a **QDialog**
        parent; otherwise it defaults to false.

        See the **default**  property for details of how **default**  and auto-
        default interact.

        **Access functions:**

        bool **autoDefault** () const
        void **setAutoDefault** (bool)
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#minimumSizeHint

        **[override virtual] QSize QPushButton::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qpushbutton.html#sizeHint

        **[override virtual] QSize QPushButton::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QSemaphoreReleaser(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsemaphorereleaser.html

    **Detailed Description**

    QSemaphoreReleaser can be used wherever you would otherwise use
    **QSemaphore::release** (). Constructing a QSemaphoreReleaser defers the
    release() call on the semaphore until the QSemaphoreReleaser is destroyed
    (see **RAII pattern** ).

    You can use this to reliably release a semaphore to avoid dead-lock in the
    face of exceptions or early returns:

    // ... do something that may throw or return early
        sem.release();

    If an early return is taken or an exception is thrown before the
    `sem.release()` call is reached, the semaphore is not released, possibly
    preventing the thread waiting in the corresponding `sem.acquire()` call from
    ever continuing execution.

    When using RAII instead:

    const **QSemaphoreReleaser**  releaser(sem);
        // ... do something that
    may throw or early return
        // implicitly calls sem.release() here and at
    every other return in between

    this can no longer happen, because the compiler will make sure that the
    QSemaphoreReleaser destructor is always called, and therefore the semaphore
    is always released.

    QSemaphoreReleaser is move-enabled and can therefore be returned from
    functions to transfer responsibility for releasing a semaphore out of a
    function or a scope:

    { // some scope
            **QSemaphoreReleaser**  releaser; // does nothing
    // ...
            if (someCondition) {
                releaser =
    **QSemaphoreReleaser** (sem);
                // ...
            }
            // ...
    } // conditionally calls sem.release(), depending on someCondition

    A QSemaphoreReleaser can be canceled by a call to **cancel** (). A canceled
    semaphore releaser will no longer call **QSemaphore::release** () in its
    destructor.

    **See also** **QMutexLocker** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsemaphorereleaser.html#QSemaphoreReleaser

        **QSemaphoreReleaser::QSemaphoreReleaser()**

        Default constructor. Creates a QSemaphoreReleaser that does nothing.
        """
        ...

    @typing.overload
    def __init__(self, sem: QSemaphore, n: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsemaphorereleaser.html#QSemaphoreReleaser-1

        **QSemaphoreReleaser::QSemaphoreReleaser(QSemaphore & sem , int n = 1)**

        Constructor. Stores the arguments and calls **sem**.release( **n** ) in
        the destructor.
        """
        ...

    def cancel(self) -> QSemaphore:
        """
        https://doc.qt.io/qt-6/qsemaphorereleaser.html#cancel

        **QSemaphore *QSemaphoreReleaser::cancel()**

        Cancels this **QSemaphoreReleaser**  such that the destructor will no
        longer call `semaphore()->release()`. Returns the value of **semaphore**
        () before this call. After this call, **semaphore** () will return
        `nullptr`.

        To enable again, assign a new **QSemaphoreReleaser** :

        releaser.cancel(); // avoid releasing old semaphore()
            releaser =
        **QSemaphoreReleaser** (sem, 42);
            // now will call sem.release(42)
        when 'releaser' is destroyed
        """
        ...

    def semaphore(self) -> QSemaphore:
        """
        https://doc.qt.io/qt-6/qsemaphorereleaser.html#semaphore

        **QSemaphore *QSemaphoreReleaser::semaphore() const**

        Returns a pointer to the **QSemaphore**  object provided to the
        constructor, or by the last move assignment, if any. Otherwise, returns
        `nullptr`.
        """
        ...

    def swap(self, other: "QSemaphoreReleaser") -> None:
        """
        https://doc.qt.io/qt-6/qsemaphorereleaser.html#swap

        **void QSemaphoreReleaser::swap(QSemaphoreReleaser & other )**

        Exchanges the responsibilities of `*this` and **other**.

        Unlike move assignment, neither of the two objects ever releases its
        semaphore, if any, as a consequence of swapping.

        Therefore this function is very fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QQuickRenderControl(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qquickrendercontrol.html

    **Detailed Description**

    **QQuickWindow**  and **QQuickView**  and their associated internal render
    loops render the Qt Quick scene onto a native window. In some cases, for
    example when integrating with 3rd party OpenGL, Vulkan, Metal, or Direct 3D
    renderers, it can be useful to get the scene into a texture that can then be
    used in arbitrary ways by the external rendering engine. Such a mechanism is
    also essential when integrating with a VR framework. QQuickRenderControl
    makes this possible in a hardware accelerated manner, unlike the
    performance-wise limited alternative of using **QQuickWindow::grabWindow**
    ()

    When using a QQuickRenderControl, the **QQuickWindow**  must not be
    **shown**  (it will not be visible on-screen) and there will not be an
    underlying native window for it. Instead, the **QQuickWindow**  instance is
    associated with the render control object, using the overload of the
    **QQuickWindow**  constructor, and a texture or image object specified via
    **QQuickWindow::setRenderTarget** (). The **QQuickWindow**  object is still
    essential, because it represents the Qt Quick scene and provides the bulk of
    the scene management and event delivery mechanisms. It does not however act
    as a real on-screen window from the windowing system's perspective.

    Management of the graphics devices, contexts, image and texture objects is
    up to the application. The device or context that will be used by Qt Quick
    must be created before calling **initialize** (). The creation of the the
    texture object can be deferred, see below. Qt 5.4 introduces the ability for
    **QOpenGLContext**  to adopt existing native contexts. Together with
    QQuickRenderControl this makes it possible to create a **QOpenGLContext**
    that shares with an external rendering engine's existing context. This new
    **QOpenGLContext**  can then be used to render the Qt Quick scene into a
    texture that is accessible by the other engine's context too. For Vulkan,
    Metal, and Direct 3D there are no Qt-provided wrappers for device objects,
    so existing ones can be passed as-is via **QQuickWindow::setGraphicsDevice**
    ().

    Loading and instantiation of the QML components happen by using a
    **QQmlEngine** . Once the root object is created, it will need to be
    parented to the **QQuickWindow** 's contentItem().

    Applications will usually have to connect to 4 important signals:

    * **QQuickWindow::sceneGraphInitialized** () Emitted at some point after
    calling **QQuickRenderControl::initialize** (). Upon this signal, the
    application is expected to create its framebuffer object and associate it
    with the **QQuickWindow** .
      * **QQuickWindow::sceneGraphInvalidated** ()
    When the scenegraph resources are released, the framebuffer object can be
    destroyed too.
      * **QQuickRenderControl::renderRequested** () Indicates
    that the scene has to be rendered by calling **render** (). After making the
    context current, applications are expected to call **render** ().
      *
    **QQuickRenderControl::sceneChanged** () Indicates that the scene has
    changed meaning that, before rendering, polishing and synchronizing is also
    necessary.

    To send events, for example mouse or keyboard events, to the scene, use
    **QCoreApplication::sendEvent** () with the **QQuickWindow**  instance as
    the receiver.

    For key events it may be also necessary to set the focus manually on the
    desired item. In practice this involves calling **forceActiveFocus** () on
    the desired item, for example the scene's root item, once it is associated
    with the scene (the **QQuickWindow** ).

    **Note:** In general QQuickRenderControl is supported in combination with
    all Qt Quick backends. However, some functionality, in particular grab(),
    may not be available in all cases.
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#QQuickRenderControl

        **QQuickRenderControl::QQuickRenderControl(QObject * parent = nullptr)**

        Constructs a QQuickRenderControl object, with parent object **parent**.
        """
        ...

    def window(self) -> "QQuickWindow":
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#window

        **[since 6.0] QQuickWindow *QQuickRenderControl::window() const**

        Returns the **QQuickWindow**  this **QQuickRenderControl**  is
        associated with.

        **Note:** A **QQuickRenderControl**  gets associated with a
        **QQuickWindow**  when constructing the **QQuickWindow** . The return
        value from this function is null before that point.

        This function was introduced in Qt 6.0.
        """
        ...

    def endFrame(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#endFrame

        **[since 6.0] void QQuickRenderControl::endFrame()**

        Specifies the end of a graphics frame. Calls to **sync** () or
        **render** () must be enclosed by calls to **beginFrame** () and
        endFrame().

        When this function is called, any graphics commands enqueued by the
        scenegraph are submitted to the context or command queue, whichever is
        applicable.

        This function was introduced in Qt 6.0.

        **See also** **beginFrame** (), **initialize** (), **sync** (),
        **render** (), **QQuickGraphicsDevice** , and **QQuickRenderTarget** .
        """
        ...

    def beginFrame(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#beginFrame

        **[since 6.0] void QQuickRenderControl::beginFrame()**

        Specifies the start of a graphics frame. Calls to **sync** () or
        **render** () must be enclosed by calls to beginFrame() and **endFrame**
        ().

        Unlike the earlier OpenGL-only world of Qt 5, rendering with other
        graphics APIs requires more well-defined points of starting and ending a
        frame. When manually driving the rendering loop via
        **QQuickRenderControl** , it now falls to the user of
        **QQuickRenderControl**  to specify these points.

        A typical update step, including initialization of rendering into an
        existing texture, could like like the following. The example snippet
        assumes Direct3D 11 but the same concepts apply other graphics APIs as
        well.

        if (!m_quickInitialized) {
                m_quickWindow->setGraphicsDevice(QQui
        ckGraphicsDevice::fromDeviceAndContext(m_engine->device(),
        m_engine->context()));

                if (!m_renderControl->initialize())
        qWarning("Failed to initialize redirected Qt Quick rendering");
        m_quickWindow->setRenderTarget(QQuickRenderTarget::fromNativeTexture({
        quint64(m_res.texture), 0 },
        QSize(QML_WIDTH, QML_HEIGHT),
        SAMPLE_COUNT));

                m_quickInitialized = true;
            }
        m_renderControl->polishItems();

            m_renderControl->beginFrame();
        m_renderControl->sync();
            m_renderControl->render();
        m_renderControl->endFrame(); // Qt Quick's rendering commands are
        submitted to the device context here

        This function was introduced in Qt 6.0.

        **See also** **endFrame** (), **initialize** (), **sync** (), **render**
        (), **QQuickGraphicsDevice** , and **QQuickRenderTarget** .
        """
        ...

    def samples(self) -> int:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#samples

        **[since 6.0] int QQuickRenderControl::samples() const**

        Returns the current sample count. 1 or 0 means no multisampling.

        This function was introduced in Qt 6.0.

        **See also** **setSamples** ().
        """
        ...

    def setSamples(self, sampleCount: int) -> None:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#setSamples

        **[since 6.0] void QQuickRenderControl::setSamples(int sampleCount )**

        Sets the number of samples to use for multisampling. When
        **sampleCount** is 0 or 1, multisampling is disabled.

        **Note:** This function is always used in combination with a multisample
        render target, which means **sampleCount** must match the sample count
        passed to QQuickRenderTarget::fromNativeTexture(), which in turn must
        match the sample count of the native texture.

        This function was introduced in Qt 6.0.

        **See also** **samples** (), **initialize** (), and
        **QQuickRenderTarget** .
        """
        ...

    def prepareThread(self, targetThread: QtCore.QThread) -> None:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#prepareThread

        **void QQuickRenderControl::prepareThread(QThread * targetThread )**

        Prepares rendering the Qt Quick scene outside the GUI thread.

        **targetThread** specifies the thread on which synchronization and
        rendering will happen. There is no need to call this function in a
        single threaded scenario.
        """
        ...

    def renderWindow(self, offset: QtCore.QPoint) -> QtGui.QWindow:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#renderWindow

        **[virtual] QWindow *QQuickRenderControl::renderWindow(QPoint * offset
        )**

        Reimplemented in subclasses to return the real window this render
        control is rendering into.

        If **offset** in non-null, it is set to the offset of the control inside
        the window.

        **Note:** While not mandatory, reimplementing this function becomes
        essential for supporting multiple screens with different device pixel
        ratios and properly positioning popup windows opened from QML. Therefore
        providing it in subclasses is highly recommended.
        """
        ...

    @staticmethod
    def renderWindowFor(
        win: "QQuickWindow", offset: typing.Optional[QtCore.QPoint] = ...
    ) -> QtGui.QWindow:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#renderWindowFor

        **[static] QWindow *QQuickRenderControl::renderWindowFor(QQuickWindow *
        win , QPoint * offset = nullptr)**

        Returns the real window that **win** is being rendered to, if any.

        If **offset** in non-null, it is set to the offset of the rendering
        inside its window.
        """
        ...

    def sync(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#sync

        **bool QQuickRenderControl::sync()**

        This function is used to synchronize the QML scene with the rendering
        scene graph.

        If a dedicated render thread is used, the GUI thread should be blocked
        for the duration of this call.

        Returns **true** if the synchronization changed the scene graph.
        """
        ...

    def render(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#render

        **void QQuickRenderControl::render()**

        Renders the scenegraph using the current context.
        """
        ...

    def polishItems(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#polishItems

        **void QQuickRenderControl::polishItems()**

        This function should be called as late as possible before **sync** ().
        In a threaded scenario, rendering can happen in parallel with this
        function.
        """
        ...

    def invalidate(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#invalidate

        **void QQuickRenderControl::invalidate()**

        Stop rendering and release resources.

        This is the equivalent of the cleanup operations that happen with a real
        **QQuickWindow**  when the window becomes hidden.

        This function is called from the destructor. Therefore there will
        typically be no need to call it directly.

        Once invalidate() has been called, it is possible to reuse the
        **QQuickRenderControl**  instance by calling **initialize** () again.

        **Note:** This function does not take
        QQuickWindow::persistentSceneGraph() or
        QQuickWindow::persistentGraphics() into account. This means that
        context-specific resources are always released.
        """
        ...

    def initialize(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#initialize

        **[since 6.0] bool QQuickRenderControl::initialize()**

        Initializes the scene graph resources. When using a graphics API, such
        as Vulkan, Metal, OpenGL, or Direct3D, for Qt Quick rendering,
        **QQuickRenderControl**  will set up an appropriate rendering engine
        when this function is called. This rendering infrastructure exists as
        long as the **QQuickRenderControl**  exists.

        To control what graphics API Qt Quick uses, call
        **QQuickWindow::setGraphicsApi** () with one of the
        **QSGRendererInterface** :GraphicsApi constants. That must be done
        before calling this function.

        To prevent the scenegraph from creating its own device and context
        objects, specify an appropriate **QQuickGraphicsDevice** , wrapping
        existing graphics objects, by calling
        **QQuickWindow::setGraphicsDevice** ().

        To configure which device extensions to enable (for example, for
        Vulkan), call **QQuickWindow::setGraphicsConfiguration** () before this
        function.

        **Note:** When using Vulkan, **QQuickRenderControl**  does not create a
        **QVulkanInstance**  automatically. Rather, it is the application's
        responsibility to create a suitable **QVulkanInstance**  and **associate
        it**  with the **QQuickWindow** . Before initializing the
        **QVulkanInstance** , it is strongly encouraged to query the list of Qt
        Quick's desired instance extensions by calling the static function
        **QQuickGraphicsConfiguration::preferredInstanceExtensions** () and to
        pass the returned list to **QVulkanInstance::setExtensions** ().

        Returns `true` on success, `false` otherwise.

        **Note:** This function does not need to be, and must not be, called
        when using the `software` adaptation of Qt Quick.

        This function was introduced in Qt 6.0.

        **See also** **QQuickRenderTarget** , **QQuickGraphicsDevice** , and
        **QQuickGraphicsConfiguration::preferredInstanceExtensions** ().
        """
        ...

    @property
    def renderRequested(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#renderRequested

        **[signal] void QQuickRenderControl::renderRequested()**

        This signal is emitted when the scene graph needs to be rendered. It is
        not necessary to call **sync** ().

        **Note:** Avoid triggering rendering directly when this signal is
        emitted. Instead, prefer deferring it by using a timer for example. This
        will lead to better performance.
        """
        ...

    @property
    def sceneChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qquickrendercontrol.html#sceneChanged

        **[signal] void QQuickRenderControl::sceneChanged()**

        This signal is emitted when the scene graph is updated, meaning that
        **polishItems** () and **sync** () needs to be called. If **sync** ()
        returns true, then **render** () needs to be called.

        **Note:** Avoid triggering polishing, synchronization and rendering
        directly when this signal is emitted. Instead, prefer deferring it by
        using a timer for example. This will lead to better performance.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QMessageLogger(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmessagelogger.html

    **Detailed Description**

    QMessageLogger is used to generate messages for the Qt logging framework.
    Usually one uses it through **qDebug** (), **qInfo** (), **qWarning** (),
    **qCritical** , or **qFatal** () functions, which are actually macros: For
    example **qDebug** () expands to QMessageLogger(__FILE__, __LINE__,
    **Q_FUNC_INFO** ).**debug** () for debug builds, and QMessageLogger(0, 0,
    0).**debug** () for release builds.

    One example of direct use is to forward errors that stem from a scripting
    language, e.g. QML:

    void statusChanged(QDeclarativeComponent::Status status) {
                if
    (status == QDeclarativeComponent::Error) {
                    foreach (const
    QDeclarativeError &error, component->errors()) {
                        const
    **QByteArray**  file = error.url().toEncoded();
    QMessageLogger(file.constData(), error.line(), 0).debug() <<
    error.description();
                    }
                }
            }

    **See also** **QMessageLogContext** , **qDebug** (), **qInfo** (),
    **qWarning** (), **qCritical** (), and **qFatal** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qmessagelogger.html#QMessageLogger-1

        **QMessageLogger::QMessageLogger()**

        Constructs a default QMessageLogger. See the other constructors to
        specify context information.
        """
        ...

    @typing.overload
    def __init__(self, file: str, line: int, function: str) -> None:
        """
        https://doc.qt.io/qt-6/qmessagelogger.html#QMessageLogger-2

        **QMessageLogger::QMessageLogger(const char * file , int line , const
        char * function )**

        Constructs a QMessageLogger to record log messages for **file** at
        **line** in **function**. The is equivalent to QMessageLogger(file,
        line, function, "default")
        """
        ...

    @typing.overload
    def __init__(self, file: str, line: int, function: str, category: str) -> None:
        """
        https://doc.qt.io/qt-6/qmessagelogger.html#QMessageLogger-3

        **QMessageLogger::QMessageLogger(const char * file , int line , const
        char * function , const char * category )**

        Constructs a QMessageLogger to record **category** messages for **file**
        at **line** in **function**.
        """
        ...

    def info(self, msg: str) -> None:
        """
        https://doc.qt.io/qt-6/qmessagelogger.html#info

        **[since 5.5] void QMessageLogger::info(const char * msg , ...) const**

        Logs an informational message specified with format **msg**. Additional
        parameters, specified by **msg** , may be used.

        This function was introduced in Qt 5.5.

        **See also** **qInfo** ().
        """
        ...

    def fatal(self, msg: str) -> None:
        """
        https://doc.qt.io/qt-6/qmessagelogger.html#fatal

        **void QMessageLogger::fatal(const char * msg , ...) const**

        Logs a fatal message specified with format **msg**. Additional
        parameters, specified by **msg** , may be used.

        **See also** **qFatal** ().
        """
        ...

    def critical(self, msg: str) -> None:
        """
        https://doc.qt.io/qt-6/qmessagelogger.html#critical

        **void QMessageLogger::critical(const char * msg , ...) const**

        Logs a critical message specified with format **msg**. Additional
        parameters, specified by **msg** , may be used.

        **See also** **qCritical** ().
        """
        ...

    def warning(self, msg: str) -> None:
        """
        https://doc.qt.io/qt-6/qmessagelogger.html#warning

        **void QMessageLogger::warning(const char * msg , ...) const**

        Logs a warning message specified with format **msg**. Additional
        parameters, specified by **msg** , may be used.

        **See also** **qWarning** ().
        """
        ...

    def debug(self, msg: str) -> None:
        """
        https://doc.qt.io/qt-6/qmessagelogger.html#debug

        **void QMessageLogger::debug(const char * msg , ...) const**

        Logs a debug message specified with format **msg**. Additional
        parameters, specified by **msg** , may be used.

        **See also** **qDebug** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QFontComboBox(QComboBox):
    """
    https://doc.qt.io/qt-6/qfontcombobox.html

    **Detailed Description**

    The combobox is populated with an alphabetized list of font family names,
    such as Arial, Helvetica, and Times New Roman. Family names are displayed
    using the actual font when possible. For fonts such as Symbol, where the
    name is not representable in the font itself, a sample of the font is
    displayed next to the family name.

    QFontComboBox is often used in toolbars, in conjunction with a **QComboBox**
    for controlling the font size and two **QToolButton** s for bold and italic.

    When the user selects a new font, the **currentFontChanged** () signal is
    emitted in addition to **currentIndexChanged** ().

    Call **setWritingSystem** () to tell QFontComboBox to show only fonts that
    support a given writing system, and **setFontFilters** () to filter out
    certain types of fonts as e.g. non scalable fonts or monospaced fonts.

    ![Screenshot of QFontComboBox on Windows Vista](images/windowsvista-
    fontcombobox.png)

    **See also** **QComboBox** , **QFont** , **QFontInfo** , **QFontMetrics** ,
    **QFontDatabase** , and **Character Map Example** .
    """

    class FontFilter(enum.Flag):
        AllFonts: QFontComboBox = ...
        ScalableFonts: QFontComboBox = ...
        NonScalableFonts: QFontComboBox = ...
        MonospacedFonts: QFontComboBox = ...
        ProportionalFonts: QFontComboBox = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qfontcombobox.html#QFontComboBox

        **QFontComboBox::QFontComboBox(QWidget * parent = nullptr)**

        Constructs a font combobox with the given **parent**.
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qfontcombobox.html#event

        **[override virtual protected] bool QFontComboBox::event(QEvent * e )**

        Reimplements: **QComboBox::event** (QEvent *event).
        """
        ...

    def setCurrentFont(self, f: QtGui.QFont) -> None:
        """
        https://doc.qt.io/qt-6/qfontcombobox.html#currentFont-prop

        **currentFont : QFont**

        This property holds the currently selected font

        **Access functions:**

        QFont **currentFont** () const
        void **setCurrentFont** (const QFont &
        **f** )

        **Notifier signal:**

        void ****currentFontChanged** ** (const QFont & **font** )

        **See also** **currentIndex**  and **currentText** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qfontcombobox.html#sizeHint

        **[override virtual] QSize QFontComboBox::sizeHint() const**

        Reimplements: **QComboBox::sizeHint() const** .
        """
        ...

    def currentFont(self) -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qfontcombobox.html#currentFont-prop

        **currentFont : QFont**

        This property holds the currently selected font

        **Access functions:**

        QFont **currentFont** () const
        void **setCurrentFont** (const QFont &
        **f** )

        **Notifier signal:**

        void ****currentFontChanged** ** (const QFont & **font** )

        **See also** **currentIndex**  and **currentText** .
        """
        ...

    def setFontFilters(self, filters: "QFontComboBox.FontFilter") -> None:
        """
        https://doc.qt.io/qt-6/qfontcombobox.html#fontFilters-prop

        **fontFilters : FontFilters**

        This property holds the filter for the combobox

        By default, all fonts are listed.

        **Access functions:**

        QFontComboBox::FontFilters **fontFilters** () const
        void
        **setFontFilters** (QFontComboBox::FontFilters **filters** )

        **See also** **writingSystem** .
        """
        ...

    def writingSystem(self) -> QtGui.QFontDatabase.WritingSystem:
        """
        https://doc.qt.io/qt-6/qfontcombobox.html#writingSystem-prop

        **writingSystem : QFontDatabase::WritingSystem**

        This property holds the writing system that serves as a filter for the
        combobox

        If **script** is **QFontDatabase::Any**  (the default), all fonts are
        listed.

        **Access functions:**

        QFontDatabase::WritingSystem **writingSystem** () const
        void
        **setWritingSystem** (QFontDatabase::WritingSystem)

        **See also** **fontFilters** .

        **Member Function Documentation**
        """
        ...

    def setWritingSystem(self, a0: QtGui.QFontDatabase.WritingSystem) -> None:
        """
        https://doc.qt.io/qt-6/qfontcombobox.html#writingSystem-prop

        **writingSystem : QFontDatabase::WritingSystem**

        This property holds the writing system that serves as a filter for the
        combobox

        If **script** is **QFontDatabase::Any**  (the default), all fonts are
        listed.

        **Access functions:**

        QFontDatabase::WritingSystem **writingSystem** () const
        void
        **setWritingSystem** (QFontDatabase::WritingSystem)

        **See also** **fontFilters** .

        **Member Function Documentation**
        """
        ...

    def fontFilters(self) -> "QFontComboBox.FontFilter":
        """
        https://doc.qt.io/qt-6/qfontcombobox.html#fontFilters-prop

        **fontFilters : FontFilters**

        This property holds the filter for the combobox

        By default, all fonts are listed.

        **Access functions:**

        QFontComboBox::FontFilters **fontFilters** () const
        void
        **setFontFilters** (QFontComboBox::FontFilters **filters** )

        **See also** **writingSystem** .
        """
        ...

    @property
    def currentFontChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfontcombobox.html#currentFontChanged

        **[signal] void QFontComboBox::currentFontChanged(const QFont & font )**

        This signal is emitted whenever the current font changes, with the new
        **font**.

        **Note:** Notifier signal for property **currentFont** .

        **See also** **currentFont** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtMultimedia import *
import enum


class QAudioFormat(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qaudioformat.html

    **Detailed Description**

    An audio format specifies how data in a raw audio stream is arranged. For
    example, how the stream is to be interpreted.

    QAudioFormat contains parameters that specify how the audio sample data is
    arranged. These are the frequency, the number of channels, and the sample
    format. The following table describes these in more detail.

    ParameterDescription
    Sample RateSamples per second of audio data in Hertz.
    Number of channelsThe number of audio channels (typically one for mono or
    two for stereo). These are the amount of consecutive samples that together
    form one frame in the stream
    Sample formatThe format of the audio samples
    in the stream

    This class is used in conjunction with **QAudioSource**  or **QAudioSink**
    to allow you to specify the parameters of the audio stream being read or
    written, or with **QAudioBuffer**  when dealing with samples in memory.

    You can obtain audio formats compatible with the audio device used through
    functions in **QAudioDevice** . This class also lets you query available
    parameter values for a device, so that you can set the parameters yourself.
    See the **QAudioDevice**  class description for details. You need to know
    the format of the audio streams you wish to play or record.

    Samples for all channels will be interleaved. One sample for each channel
    for the same instant in time is referred to as a frame in Qt Multimedia (and
    other places).
    """

    class SampleFormat(enum.Enum):
        Unknown: QAudioFormat = ...
        UInt8: QAudioFormat = ...
        Int16: QAudioFormat = ...
        Int32: QAudioFormat = ...
        Float: QAudioFormat = ...

    class ChannelConfig(enum.Enum):
        ChannelConfigUnknown: QAudioFormat = ...
        ChannelConfigMono: QAudioFormat = ...
        ChannelConfigStereo: QAudioFormat = ...
        ChannelConfig2Dot1: QAudioFormat = ...
        ChannelConfigSurround5Dot0: QAudioFormat = ...
        ChannelConfigSurround5Dot1: QAudioFormat = ...
        ChannelConfigSurround7Dot0: QAudioFormat = ...
        ChannelConfigSurround7Dot1: QAudioFormat = ...

    class AudioChannelPosition(enum.Enum):
        UnknownPosition: QAudioFormat = ...
        FrontLeft: QAudioFormat = ...
        FrontRight: QAudioFormat = ...
        FrontCenter: QAudioFormat = ...
        LFE: QAudioFormat = ...
        BackLeft: QAudioFormat = ...
        BackRight: QAudioFormat = ...
        FrontLeftOfCenter: QAudioFormat = ...
        FrontRightOfCenter: QAudioFormat = ...
        BackCenter: QAudioFormat = ...
        LFE2: QAudioFormat = ...
        SideLeft: QAudioFormat = ...
        SideRight: QAudioFormat = ...
        TopFrontLeft: QAudioFormat = ...
        TopFrontRight: QAudioFormat = ...
        TopFrontCenter: QAudioFormat = ...
        TopCenter: QAudioFormat = ...
        TopBackLeft: QAudioFormat = ...
        TopBackRight: QAudioFormat = ...
        TopSideLeft: QAudioFormat = ...
        TopSideRight: QAudioFormat = ...
        TopBackCenter: QAudioFormat = ...
        BottomFrontCenter: QAudioFormat = ...
        BottomFrontLeft: QAudioFormat = ...
        BottomFrontRight: QAudioFormat = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#QAudioFormat

        **[default] QAudioFormat::QAudioFormat()**

        Constructs a new audio format.

        Values are initialized as follows:

        * **sampleRate** () = 0
          * **channelCount** () = 0
          * **sampleFormat**
        () = **QAudioFormat::Unknown**
        """
        ...

    @typing.overload
    def __init__(self, a0: "QAudioFormat") -> None:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#QAudioFormat-1

        **[default] QAudioFormat::QAudioFormat(const QAudioFormat & other )**

        Construct a new audio format using **other**.
        """
        ...

    def normalizedSampleValue(self, sample: PyQt6.sip.voidptr) -> float:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#normalizedSampleValue

        **float QAudioFormat::normalizedSampleValue(const void * sample )
        const**

        Normalizes the **sample** value to a number between -1 and 1. The method
        depends on the QaudioFormat.
        """
        ...

    def bytesPerSample(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#bytesPerSample

        **int QAudioFormat::bytesPerSample() const**

        Returns the number of bytes required to represent one sample in this
        format.

        Returns 0 if this format is invalid.
        """
        ...

    def sampleFormat(self) -> "QAudioFormat.SampleFormat":
        """
        https://doc.qt.io/qt-6/qaudioformat.html#sampleFormat

        **QAudioFormat::SampleFormat QAudioFormat::sampleFormat() const**

        Returns the current sample format.

        **See also** **setSampleFormat** ().
        """
        ...

    def setSampleFormat(self, f: "QAudioFormat.SampleFormat") -> None:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#setSampleFormat

        **void QAudioFormat::setSampleFormat(QAudioFormat::SampleFormat format
        )**

        Sets the sample format to **format**.

        **See also** **sampleFormat** () and **QAudioFormat::SampleFormat** .
        """
        ...

    def channelOffset(self, channel: "QAudioFormat.AudioChannelPosition") -> int:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#channelOffset

        **int QAudioFormat::channelOffset(QAudioFormat::AudioChannelPosition
        channel ) const**

        Returns the position of a certain audio **channel** inside an audio
        frame for the given format. Returns -1 if the channel does not exist for
        this format or the channel configuration is unknown.
        """
        ...

    def channelConfig(self) -> "QAudioFormat.ChannelConfig":
        """
        https://doc.qt.io/qt-6/qaudioformat.html#channelConfig-1

        **QAudioFormat::ChannelConfig QAudioFormat::channelConfig() const**

        Returns the current channel configuration.
        """
        ...

    def setChannelConfig(self, config: "QAudioFormat.ChannelConfig") -> None:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#setChannelConfig

        **void QAudioFormat::setChannelConfig(QAudioFormat::ChannelConfig config
        )**

        Sets the channel configuration to **config**.

        Sets the channel configuration of the audio format to one of the
        standard audio channel configurations.

        **Note:** that this will also modify the channel count.

        **See also** **channelConfig** ().
        """
        ...

    def bytesPerFrame(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#bytesPerFrame

        **int QAudioFormat::bytesPerFrame() const**

        Returns the number of bytes required to represent one frame (a sample in
        each channel) in this format.

        Returns 0 if this format is invalid.
        """
        ...

    def durationForFrames(self, frameCount: int) -> int:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#durationForFrames

        **qint64 QAudioFormat::durationForFrames(qint32 frameCount ) const**

        Return the number of microseconds represented by **frameCount** frames
        in this format.
        """
        ...

    def framesForDuration(self, duration: int) -> int:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#framesForDuration

        **qint32 QAudioFormat::framesForDuration(qint64 microseconds ) const**

        Returns the number of frames required to represent **microseconds** in
        this format.

        Note that some rounding may occur if **microseconds** is not an exact
        fraction of the **sampleRate** ().
        """
        ...

    def framesForBytes(self, byteCount: int) -> int:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#framesForBytes

        **qint32 QAudioFormat::framesForBytes(qint32 byteCount ) const**

        Returns the number of frames represented by **byteCount** in this
        format.

        Note that some rounding may occur if **byteCount** is not an exact
        multiple of the number of bytes per frame.

        Each frame has one sample per channel.

        **See also** **framesForDuration** ().
        """
        ...

    def bytesForFrames(self, frameCount: int) -> int:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#bytesForFrames

        **qint32 QAudioFormat::bytesForFrames(qint32 frameCount ) const**

        Returns the number of bytes required for **frameCount** frames of this
        format.

        Returns 0 if this format is not valid.

        **See also** **bytesForDuration** ().
        """
        ...

    def durationForBytes(self, byteCount: int) -> int:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#durationForBytes

        **qint64 QAudioFormat::durationForBytes(qint32 bytes ) const**

        Returns the number of microseconds represented by **bytes** in this
        format.

        Returns 0 if this format is not valid.

        Note that some rounding may occur if **bytes** is not an exact multiple
        of the number of bytes per frame.

        **See also** **bytesForDuration** ().
        """
        ...

    def bytesForDuration(self, duration: int) -> int:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#bytesForDuration

        **qint32 QAudioFormat::bytesForDuration(qint64 microseconds ) const**

        Returns the number of bytes required for this audio format for
        **microseconds**.

        Returns 0 if this format is not valid.

        Note that some rounding may occur if **microseconds** is not an exact
        fraction of the **sampleRate** ().

        **See also** **durationForBytes** ().
        """
        ...

    def channelCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#channelCount

        **int QAudioFormat::channelCount() const**

        Returns the current channel count value.

        **See also** **setChannelCount** ().
        """
        ...

    def setChannelCount(self, channelCount: int) -> None:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#setChannelCount

        **void QAudioFormat::setChannelCount(int channels )**

        Sets the channel count to **channels**. Setting this also sets the
        channel config to **ChannelConfigUnknown** .

        **See also** **channelCount** ().
        """
        ...

    def sampleRate(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#sampleRate

        **int QAudioFormat::sampleRate() const**

        Returns the current sample rate in Hertz.

        **See also** **setSampleRate** ().
        """
        ...

    def setSampleRate(self, sampleRate: int) -> None:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#setSampleRate

        **void QAudioFormat::setSampleRate(int samplerate )**

        Sets the sample rate to **samplerate** in Hertz.

        **See also** **sampleRate** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qaudioformat.html#isValid

        **bool QAudioFormat::isValid() const**

        Returns `true` if all of the parameters are valid.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsSceneDragDropEvent(QGraphicsSceneEvent):
    """
    https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html

    **Detailed Description**

    **QGraphicsView**  inherits the drag and drop functionality provided by
    **QWidget** . When it receives a drag and drop event, it translates it to a
    QGraphicsSceneDragDropEvent.

    QGraphicsSceneDragDropEvent stores events of type GraphicsSceneDragEnter,
    GraphicsSceneDragLeave, GraphicsSceneDragMove, or GraphicsSceneDrop.

    QGraphicsSceneDragDropEvent contains the position of the mouse cursor in
    both item, scene, and screen coordinates; this can be retrieved with **pos**
    (), **scenePos** (), and **screenPos** ().

    The scene sends the event to the first **QGraphicsItem**  under the mouse
    cursor that accepts drops; a graphics item is set to accept drops with
    **setAcceptDrops** ().
    """

    def mimeData(self) -> QtCore.QMimeData:
        """
        https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html#mimeData

        **const QMimeData *QGraphicsSceneDragDropEvent::mimeData() const**

        This function returns the MIME data of the event.
        """
        ...

    def source(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html#source

        **QWidget *QGraphicsSceneDragDropEvent::source() const**

        This function returns the **QGraphicsView**  that created the
        **QGraphicsSceneDragDropEvent** .
        """
        ...

    def setDropAction(self, action: QtCore.Qt.DropAction) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html#setDropAction

        **void QGraphicsSceneDragDropEvent::setDropAction(Qt::DropAction action
        )**

        This function lets the receiver of the drop set the drop action that was
        performed to **action** , which should be one of the **possible
        actions** . Call `accept()` in stead of `acceptProposedAction()` if you
        use this function.

        **See also** **dropAction** (), **accept** (), and **possibleActions**
        ().
        """
        ...

    def dropAction(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html#dropAction

        **Qt::DropAction QGraphicsSceneDragDropEvent::dropAction() const**

        Returns the action that was performed in this drag and drop. This should
        be set by the receiver of the drop and is returned by **QDrag::exec**
        ().

        **See also** **setDropAction** () and **acceptProposedAction** ().
        """
        ...

    def acceptProposedAction(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html#acceptProposedAc
        tion

        **void QGraphicsSceneDragDropEvent::acceptProposedAction()**

        Sets the proposed action as accepted, i.e, the drop action is set to the
        proposed action. This is equal to:

        setDropAction(proposedAction());

        When using this function, one should not call `accept()`.

        **See also** **dropAction** (), **setDropAction** (), and
        **proposedAction** ().
        """
        ...

    def proposedAction(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html#proposedAction

        **Qt::DropAction QGraphicsSceneDragDropEvent::proposedAction() const**

        Returns the drop action that is proposed, i.e., preferred. The action
        must be one of the possible actions as defined by `possibleActions()`.

        **See also** **Qt::DropAction**  and **possibleActions** ().
        """
        ...

    def possibleActions(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html#possibleActions

        **Qt::DropActions QGraphicsSceneDragDropEvent::possibleActions() const**

        Returns the possible drop actions that the drag and drop can result in.

        **See also** **Qt::DropActions** .
        """
        ...

    def modifiers(self) -> QtCore.Qt.KeyboardModifier:
        """
        https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html#modifiers

        **Qt::KeyboardModifiers QGraphicsSceneDragDropEvent::modifiers() const**

        Returns the keyboard modifiers that were pressed when the drag and drop
        event was created.

        **See also** **Qt::KeyboardModifiers** .
        """
        ...

    def buttons(self) -> QtCore.Qt.MouseButton:
        """
        https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html#buttons

        **Qt::MouseButtons QGraphicsSceneDragDropEvent::buttons() const**

        Returns a **Qt::MouseButtons**  value indicating which buttons were
        pressed on the mouse when this mouse event was generated.

        **See also** **Qt::MouseButtons** .
        """
        ...

    def screenPos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html#screenPos

        **QPoint QGraphicsSceneDragDropEvent::screenPos() const**

        Returns the position of the mouse relative to the screen.

        **See also** **pos** () and **scenePos** ().
        """
        ...

    def scenePos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html#scenePos

        **QPointF QGraphicsSceneDragDropEvent::scenePos() const**

        Returns the position of the mouse in scene coordinates.

        **See also** **pos** () and **screenPos** ().
        """
        ...

    def pos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenedragdropevent.html#pos

        **QPointF QGraphicsSceneDragDropEvent::pos() const**

        Returns the mouse position of the event relative to the view that sent
        the event.

        **See also** **QGraphicsView** , **screenPos** (), and **scenePos** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QEventLoopLocker(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qeventlooplocker.html

    **Detailed Description**

    The QEventLoopLocker operates on particular objects - either a
    **QCoreApplication**  instance, a **QEventLoop**  instance or a **QThread**
    instance.

    This makes it possible to, for example, run a batch of jobs with an event
    loop and exit that event loop after the last job is finished. That is
    accomplished by keeping a QEventLoopLocker with each job instance.

    The variant which operates on **QCoreApplication**  makes it possible to
    finish asynchronously running jobs after the last gui window has been
    closed. This can be useful for example for running a job which uploads data
    to a network.

    **See also** **QEventLoop**  and **QCoreApplication** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qeventlooplocker.html#QEventLoopLocker

        **QEventLoopLocker::QEventLoopLocker()**

        Creates an event locker operating on the **QCoreApplication** .

        The application will quit when there are no more QEventLoopLockers
        operating on it.

        **See also** **QCoreApplication::quit** () and
        **QCoreApplication::isQuitLockEnabled** ().
        """
        ...

    @typing.overload
    def __init__(self, loop: QEventLoop) -> None:
        """
        https://doc.qt.io/qt-6/qeventlooplocker.html#QEventLoopLocker-1

        **QEventLoopLocker::QEventLoopLocker(QEventLoop * loop )**

        Creates an event locker operating on the **loop**.

        This particular **QEventLoop**  will quit when there are no more
        QEventLoopLockers operating on it.

        **See also** **QEventLoop::quit** ().
        """
        ...

    @typing.overload
    def __init__(self, thread: "QThread") -> None:
        """
        https://doc.qt.io/qt-6/qeventlooplocker.html#QEventLoopLocker-2

        **QEventLoopLocker::QEventLoopLocker(QThread * thread )**

        Creates an event locker operating on the **thread**.

        This particular **QThread**  will quit when there are no more
        QEventLoopLockers operating on it.

        **See also** **QThread::quit** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QKeySequenceEdit(QWidget):
    """
    https://doc.qt.io/qt-6/qkeysequenceedit.html

    **Detailed Description**

    This widget lets the user choose a **QKeySequence** , which is usually used
    as a shortcut. The recording is initiated when the widget receives the focus
    and ends one second after the user releases the last key.

    **See also** **QKeySequenceEdit::keySequence** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qkeysequenceedit.html#QKeySequenceEdit

        **QKeySequenceEdit::QKeySequenceEdit(QWidget * parent = nullptr)**

        Constructs a QKeySequenceEdit widget with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        keySequence: typing.Union[
            QtGui.QKeySequence, QtGui.QKeySequence.StandardKey, str, int
        ],
        parent: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qkeysequenceedit.html#QKeySequenceEdit-1

        **QKeySequenceEdit::QKeySequenceEdit(const QKeySequence & keySequence ,
        QWidget * parent = nullptr)**

        Constructs a QKeySequenceEdit widget with the given **keySequence** and
        **parent**.
        """
        ...

    def timerEvent(self, a0: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qkeysequenceedit.html#timerEvent

        **[override virtual protected] void
        QKeySequenceEdit::timerEvent(QTimerEvent * e )**

        Reimplements: **QObject::timerEvent** (QTimerEvent *event).
        """
        ...

    def keyReleaseEvent(self, a0: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qkeysequenceedit.html#keyReleaseEvent

        **[override virtual protected] void
        QKeySequenceEdit::keyReleaseEvent(QKeyEvent * e )**

        Reimplements: **QWidget::keyReleaseEvent** (QKeyEvent *event).
        """
        ...

    def keyPressEvent(self, a0: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qkeysequenceedit.html#keyPressEvent

        **[override virtual protected] void
        QKeySequenceEdit::keyPressEvent(QKeyEvent * e )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qkeysequenceedit.html#event

        **[override virtual protected] bool QKeySequenceEdit::event(QEvent * e
        )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qkeysequenceedit.html#clear

        **[slot] void QKeySequenceEdit::clear()**

        Clears the current key sequence.
        """
        ...

    def setKeySequence(
        self,
        keySequence: typing.Union[
            QtGui.QKeySequence, QtGui.QKeySequence.StandardKey, str, int
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qkeysequenceedit.html#keySequence-prop

        **keySequence : QKeySequence**

        This property contains the currently chosen key sequence.

        The shortcut can be changed by the user or via setter function.

        **Access functions:**

        QKeySequence **keySequence** () const
        void **setKeySequence** (const
        QKeySequence & **keySequence** )

        **Notifier signal:**

        void **keySequenceChanged** (const QKeySequence & **keySequence** )

        **Member Function Documentation**
        """
        ...

    def keySequence(self) -> QtGui.QKeySequence:
        """
        https://doc.qt.io/qt-6/qkeysequenceedit.html#keySequence-prop

        **keySequence : QKeySequence**

        This property contains the currently chosen key sequence.

        The shortcut can be changed by the user or via setter function.

        **Access functions:**

        QKeySequence **keySequence** () const
        void **setKeySequence** (const
        QKeySequence & **keySequence** )

        **Notifier signal:**

        void **keySequenceChanged** (const QKeySequence & **keySequence** )

        **Member Function Documentation**
        """
        ...

    @property
    def editingFinished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qkeysequenceedit.html#editingFinished

        **[signal] void QKeySequenceEdit::editingFinished()**

        This signal is emitted when the user finishes entering the shortcut.

        **Note:** there is a one second delay before releasing the last key and
        emitting this signal.
        """
        ...

    @property
    def keySequenceChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *


class QUdpSocket(QAbstractSocket):
    """
    https://doc.qt.io/qt-6/qudpsocket.html

    **Detailed Description**

    UDP (User Datagram Protocol) is a lightweight, unreliable, datagram-
    oriented, connectionless protocol. It can be used when reliability isn't
    important. QUdpSocket is a subclass of **QAbstractSocket**  that allows you
    to send and receive UDP datagrams.

    The most common way to use this class is to bind to an address and port
    using **bind** (), then call **writeDatagram** () and **readDatagram** () /
    **receiveDatagram** () to transfer data. If you want to use the standard
    **QIODevice**  functions **read** (), **readLine** (), **write** (), etc.,
    you must first connect the socket directly to a peer by calling
    **connectToHost** ().

    The socket emits the **bytesWritten** () signal every time a datagram is
    written to the network. If you just want to send datagrams, you don't need
    to call **bind** ().

    The **readyRead** () signal is emitted whenever datagrams arrive. In that
    case, **hasPendingDatagrams** () returns `true`. Call
    **pendingDatagramSize** () to obtain the size of the first pending datagram,
    and **readDatagram** () or **receiveDatagram** () to read it.

    **Note:** An incoming datagram should be read when you receive the
    **readyRead** () signal, otherwise this signal will not be emitted for the
    next datagram.

    Example:

    void Server::initSocket()
        {
            udpSocket = new **QUdpSocket**
    (this);
            udpSocket->bind(**QHostAddress** ::LocalHost, 7755);
    connect(udpSocket, &**QUdpSocket** ::readyRead,
                    this,
    &Server::readPendingDatagrams);
        }

        void
    Server::readPendingDatagrams()
        {
            while
    (udpSocket->hasPendingDatagrams()) {
                **QNetworkDatagram**
    datagram = udpSocket->receiveDatagram();
    processTheDatagram(datagram);
            }
        }

    QUdpSocket also supports UDP multicast. Use **joinMulticastGroup** () and
    **leaveMulticastGroup** () to control group membership, and
    **QAbstractSocket::MulticastTtlOption**  and
    **QAbstractSocket::MulticastLoopbackOption**  to set the TTL and loopback
    socket options. Use **setMulticastInterface** () to control the outgoing
    interface for multicast datagrams, and **multicastInterface** () to query
    it.

    With QUdpSocket, you can also establish a virtual connection to a UDP server
    using **connectToHost** () and then use **read** () and **write** () to
    exchange datagrams without specifying the receiver for each datagram.

    The **Broadcast Sender** , **Broadcast Receiver** , **Multicast Sender** ,
    and **Multicast Receiver**  examples illustrate how to use QUdpSocket in
    applications.

    **See also** **QTcpSocket**  and **QNetworkDatagram** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#QUdpSocket

        **QUdpSocket::QUdpSocket(QObject * parent = nullptr)**

        Creates a QUdpSocket object.

        **parent** is passed to the **QObject**  constructor.

        **See also** **socketType** ().
        """
        ...

    def setMulticastInterface(self, iface: QNetworkInterface) -> None:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#setMulticastInterface

        **void QUdpSocket::setMulticastInterface(const QNetworkInterface & iface
        )**

        Sets the outgoing interface for multicast datagrams to the interface
        **iface**. This corresponds to the IP_MULTICAST_IF socket option for
        IPv4 sockets and the IPV6_MULTICAST_IF socket option for IPv6 sockets.
        The socket must be in BoundState, otherwise this function does nothing.

        **See also** **multicastInterface** (), **joinMulticastGroup** (), and
        **leaveMulticastGroup** ().
        """
        ...

    def multicastInterface(self) -> QNetworkInterface:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#multicastInterface

        **QNetworkInterface QUdpSocket::multicastInterface() const**

        Returns the interface for the outgoing interface for multicast
        datagrams. This corresponds to the IP_MULTICAST_IF socket option for
        IPv4 sockets and the IPV6_MULTICAST_IF socket option for IPv6 sockets.
        If no interface has been previously set, this function returns an
        invalid **QNetworkInterface** . The socket must be in BoundState,
        otherwise an invalid **QNetworkInterface**  is returned.

        **See also** **setMulticastInterface** ().
        """
        ...

    @typing.overload
    def leaveMulticastGroup(
        self, groupAddress: typing.Union[QHostAddress, QHostAddress.SpecialAddress]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#leaveMulticastGroup

        **bool QUdpSocket::leaveMulticastGroup(const QHostAddress & groupAddress
        )**

        Leaves the multicast group specified by **groupAddress** on the default
        interface chosen by the operating system. The socket must be in
        BoundState, otherwise an error occurs.

        This function returns `true` if successful; otherwise it returns `false`
        and sets the socket error accordingly.

        **Note:** This function should be called with the same arguments as were
        passed to **joinMulticastGroup** ().

        **See also** **joinMulticastGroup** ().
        """
        ...

    @typing.overload
    def leaveMulticastGroup(
        self,
        groupAddress: typing.Union[QHostAddress, QHostAddress.SpecialAddress],
        iface: QNetworkInterface,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#leaveMulticastGroup-1

        **bool QUdpSocket::leaveMulticastGroup(const QHostAddress & groupAddress
        , const QNetworkInterface & iface )**

        This is an overloaded function.

        Leaves the multicast group specified by **groupAddress** on the
        interface **iface**.

        **Note:** This function should be called with the same arguments as were
        passed to **joinMulticastGroup** ().

        **See also** **joinMulticastGroup** ().
        """
        ...

    @typing.overload
    def joinMulticastGroup(
        self, groupAddress: typing.Union[QHostAddress, QHostAddress.SpecialAddress]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#joinMulticastGroup

        **bool QUdpSocket::joinMulticastGroup(const QHostAddress & groupAddress
        )**

        Joins the multicast group specified by **groupAddress** on the default
        interface chosen by the operating system. The socket must be in
        BoundState, otherwise an error occurs.

        Note that if you are attempting to join an IPv4 group, your socket must
        not be bound using IPv6 (or in dual mode, using **QHostAddress::Any** ).
        You must use **QHostAddress::AnyIPv4**  instead.

        This function returns `true` if successful; otherwise it returns `false`
        and sets the socket error accordingly.

        **Note:** Joining IPv6 multicast groups without an interface selection
        is not supported in all operating systems. Consider using the overload
        where the interface is specified.

        **See also** **leaveMulticastGroup** ().
        """
        ...

    @typing.overload
    def joinMulticastGroup(
        self,
        groupAddress: typing.Union[QHostAddress, QHostAddress.SpecialAddress],
        iface: QNetworkInterface,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#joinMulticastGroup-1

        **bool QUdpSocket::joinMulticastGroup(const QHostAddress & groupAddress
        , const QNetworkInterface & iface )**

        This is an overloaded function.

        Joins the multicast group address **groupAddress** on the interface
        **iface**.

        **See also** **leaveMulticastGroup** ().
        """
        ...

    @typing.overload
    def writeDatagram(
        self,
        a0: PyQt6.sip.Buffer,
        a1: typing.Union[QHostAddress, QHostAddress.SpecialAddress],
        a2: int,
    ) -> int:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#writeDatagram

        **qint64 QUdpSocket::writeDatagram(const char * data , qint64 size ,
        const QHostAddress & address , quint16 port )**

        Sends the datagram at **data** of size **size** to the host address
        **address** at port **port**. Returns the number of bytes sent on
        success; otherwise returns -1.

        Datagrams are always written as one block. The maximum size of a
        datagram is highly platform-dependent, but can be as low as 8192 bytes.
        If the datagram is too large, this function will return -1 and **error**
        () will return DatagramTooLargeError.

        Sending datagrams larger than 512 bytes is in general disadvised, as
        even if they are sent successfully, they are likely to be fragmented by
        the IP layer before arriving at their final destination.

        **Warning:** Calling this function on a connected UDP socket may result
        in an error and no packet being sent. If you are using a connected
        socket, use **write** () to send datagrams.

        **See also** **readDatagram** () and **write** ().
        """
        ...

    @typing.overload
    def writeDatagram(self, datagram: QNetworkDatagram) -> int:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#writeDatagram-1

        **[since 5.8] qint64 QUdpSocket::writeDatagram(const QNetworkDatagram &
        datagram )**

        This is an overloaded function.

        Sends the datagram **datagram** to the host address and port numbers
        contained in **datagram** , using the network interface and hop count
        limits also set there. If the destination address and port numbers are
        unset, this function will send to the address that was passed to
        **connectToHost** ().

        If the destination address is IPv6 with a non-empty **scope id**  but
        differs from the interface index in **datagram** , it is undefined which
        interface the operating system will choose to send on.

        The function returns the number of bytes sent if it succeeded or -1 if
        it encountered an error.

        **Warning:** Calling this function on a connected UDP socket may result
        in an error and no packet being sent. If you are using a connected
        socket, use **write** () to send datagrams.

        This function was introduced in Qt 5.8.

        **See also** **QNetworkDatagram::setDestination** (),
        **QNetworkDatagram::setHopLimit** (), and
        **QNetworkDatagram::setInterfaceIndex** ().
        """
        ...

    def receiveDatagram(self, maxSize: int = ...) -> QNetworkDatagram:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#receiveDatagram

        **[since 5.8] QNetworkDatagram QUdpSocket::receiveDatagram(qint64
        maxSize = -1)**

        Receives a datagram no larger than **maxSize** bytes and returns it in
        the **QNetworkDatagram**  object, along with the sender's host address
        and port. If possible, this function will also try to determine the
        datagram's destination address, port, and the number of hop counts at
        reception time.

        On failure, returns a **QNetworkDatagram**  that reports **not valid** .

        If **maxSize** is too small, the rest of the datagram will be lost. If
        **maxSize** is 0, the datagram will be discarded. If **maxSize** is -1
        (the default), this function will attempt to read the entire datagram.

        This function was introduced in Qt 5.8.

        **See also** **writeDatagram** (), **hasPendingDatagrams** (), and
        **pendingDatagramSize** ().
        """
        ...

    def readDatagram(self, maxlen: int) -> typing.Tuple[bytes, QHostAddress, int]:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#readDatagram

        **qint64 QUdpSocket::readDatagram(char * data , qint64 maxSize ,
        QHostAddress * address = nullptr, quint16 * port = nullptr)**

        Receives a datagram no larger than **maxSize** bytes and stores it in
        **data**. The sender's host address and port is stored in * **address**
        and * **port** (unless the pointers are `nullptr`).

        Returns the size of the datagram on success; otherwise returns -1.

        If **maxSize** is too small, the rest of the datagram will be lost. To
        avoid loss of data, call **pendingDatagramSize** () to determine the
        size of the pending datagram before attempting to read it. If
        **maxSize** is 0, the datagram will be discarded.

        **See also** **writeDatagram** (), **hasPendingDatagrams** (), and
        **pendingDatagramSize** ().
        """
        ...

    def pendingDatagramSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#pendingDatagramSize

        **qint64 QUdpSocket::pendingDatagramSize() const**

        Returns the size of the first pending UDP datagram. If there is no
        datagram available, this function returns -1.

        **See also** **hasPendingDatagrams** () and **readDatagram** ().
        """
        ...

    def hasPendingDatagrams(self) -> bool:
        """
        https://doc.qt.io/qt-6/qudpsocket.html#hasPendingDatagrams

        **bool QUdpSocket::hasPendingDatagrams() const**

        Returns `true` if at least one datagram is waiting to be read; otherwise
        returns `false`.

        **See also** **pendingDatagramSize** () and **readDatagram** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QIconEngine(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qiconengine.html

    **Detailed Description**

    An icon engine provides the rendering functions for a **QIcon** . Each icon
    has a corresponding icon engine that is responsible for drawing the icon
    with a requested size, mode and state.

    The icon is rendered by the **paint** () function, and the icon can
    additionally be obtained as a pixmap with the **pixmap** () function (the
    default implementation simply uses **paint** () to achieve this). The
    **addPixmap** () function can be used to add new pixmaps to the icon engine,
    and is used by **QIcon**  to add specialized custom pixmaps.

    The **paint** (), **pixmap** (), and **addPixmap** () functions are all
    virtual, and can therefore be reimplemented in subclasses of QIconEngine.

    **See also** **QIconEnginePlugin** .
    """

    class IconEngineHook(enum.Enum):
        IsNullHook: QIconEngine = ...
        ScaledPixmapHook: QIconEngine = ...

    class ScaledPixmapArgument(PyQt6.sip.simplewrapper):
        mode: QIcon = ...
        pixmap: QPixmap = ...
        scale: float = ...
        size: QtCore = ...
        state: QIcon = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QIconEngine.ScaledPixmapArgument") -> None:
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qiconengine.html#QIconEngine

        **[since 5.6] QIconEngine::QIconEngine()**

        Constructs the icon engine.

        This function was introduced in Qt 5.6.
        """
        ...

    @typing.overload
    def __init__(self, other: "QIconEngine") -> None:
        """
        https://doc.qt.io/qt-6/qiconengine.html#QIconEngine

        **[since 5.6] QIconEngine::QIconEngine()**

        Constructs the icon engine.

        This function was introduced in Qt 5.6.
        """
        ...

    def scaledPixmap(
        self, size: QtCore.QSize, mode: QIcon.Mode, state: QIcon.State, scale: float
    ) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qiconengine.html#scaledPixmap

        **[virtual, since 5.9] QPixmap QIconEngine::scaledPixmap(const QSize &
        size , QIcon::Mode mode , QIcon::State state , qreal scale )**

        Returns a pixmap for the given **size** , **mode** , **state** and
        **scale**.

        The **scale** argument is typically equal to the **device pixel ratio**
        of the display.

        **Note:** This is a helper method and the actual work is done by the
        **virtual_hook** () method, hence this method depends on icon engine
        support and may not work with all icon engines.

        **Note:** Some engines may cast **scale** to an integer.

        This function was introduced in Qt 5.9.

        **See also** **ScaledPixmapArgument** .
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qiconengine.html#isNull

        **[virtual, since 5.7] bool QIconEngine::isNull()**

        Returns true if this icon engine represent a null **QIcon** .

        **Note:** This is a helper method and the actual work is done by the
        **virtual_hook** () method, hence this method depends on icon engine
        support and may not work with all icon engines.

        This function was introduced in Qt 5.7.
        """
        ...

    def iconName(self) -> str:
        """
        https://doc.qt.io/qt-6/qiconengine.html#iconName

        **[virtual] QString QIconEngine::iconName()**

        Returns the name used to create the engine, if available.
        """
        ...

    def availableSizes(
        self, mode: QIcon.Mode = ..., state: QIcon.State = ...
    ) -> typing.List[QtCore.QSize]:
        """
        https://doc.qt.io/qt-6/qiconengine.html#availableSizes

        **[virtual] QList<QSize> QIconEngine::availableSizes(QIcon::Mode mode =
        QIcon::Normal, QIcon::State state = QIcon::Off)**

        Returns sizes of all images that are contained in the engine for the
        specific **mode** and **state**.
        """
        ...

    def write(self, out: QtCore.QDataStream) -> bool:
        """
        https://doc.qt.io/qt-6/qiconengine.html#write

        **[virtual] bool QIconEngine::write(QDataStream & out ) const**

        Writes the contents of this engine to the **QDataStream**  **out**.
        Returns `true` if the contents were written; otherwise returns `false`.

        **QIconEngine** 's default implementation always return false.
        """
        ...

    def read(self, in_: QtCore.QDataStream) -> bool:
        """
        https://doc.qt.io/qt-6/qiconengine.html#read

        **[virtual] bool QIconEngine::read(QDataStream & in )**

        Reads icon engine contents from the **QDataStream**  **in**. Returns
        true if the contents were read; otherwise returns `false`.

        **QIconEngine** 's default implementation always return false.
        """
        ...

    def clone(self) -> "QIconEngine":
        """
        https://doc.qt.io/qt-6/qiconengine.html#clone

        **[pure virtual] QIconEngine *QIconEngine::clone() const**

        Reimplement this method to return a clone of this icon engine.
        """
        ...

    def key(self) -> str:
        """
        https://doc.qt.io/qt-6/qiconengine.html#key

        **[virtual] QString QIconEngine::key() const**

        Returns a key that identifies this icon engine.
        """
        ...

    def addFile(
        self, fileName: str, size: QtCore.QSize, mode: QIcon.Mode, state: QIcon.State
    ) -> None:
        """
        https://doc.qt.io/qt-6/qiconengine.html#addFile

        **[virtual] void QIconEngine::addFile(const QString & fileName , const
        QSize & size , QIcon::Mode mode , QIcon::State state )**

        Called by **QIcon::addFile** (). Adds a specialized pixmap from the file
        with the given **fileName** , **size** , **mode** and **state**. The
        default pixmap-based engine stores any supplied file names, and it loads
        the pixmaps on demand instead of using scaled pixmaps if the size of a
        pixmap matches the size of icon requested. Custom icon engines that
        implement scalable vector formats are free to ignores any extra files.
        """
        ...

    def addPixmap(self, pixmap: QPixmap, mode: QIcon.Mode, state: QIcon.State) -> None:
        """
        https://doc.qt.io/qt-6/qiconengine.html#addPixmap

        **[virtual] void QIconEngine::addPixmap(const QPixmap & pixmap ,
        QIcon::Mode mode , QIcon::State state )**

        Called by **QIcon::addPixmap** (). Adds a specialized **pixmap** for the
        given **mode** and **state**. The default pixmap-based engine stores any
        supplied pixmaps, and it uses them instead of scaled pixmaps if the size
        of a pixmap matches the size of icon requested. Custom icon engines that
        implement scalable vector formats are free to ignores any extra pixmaps.
        """
        ...

    def pixmap(
        self, size: QtCore.QSize, mode: QIcon.Mode, state: QIcon.State
    ) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qiconengine.html#pixmap

        **[virtual] QPixmap QIconEngine::pixmap(const QSize & size , QIcon::Mode
        mode , QIcon::State state )**

        Returns the icon as a pixmap with the required **size** , **mode** , and
        **state**. The default implementation creates a new pixmap and calls
        **paint** () to fill it.
        """
        ...

    def actualSize(
        self, size: QtCore.QSize, mode: QIcon.Mode, state: QIcon.State
    ) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qiconengine.html#actualSize

        **[virtual] QSize QIconEngine::actualSize(const QSize & size ,
        QIcon::Mode mode , QIcon::State state )**

        Returns the actual size of the icon the engine provides for the
        requested **size** , **mode** and **state**. The default implementation
        returns the given **size**.
        """
        ...

    def paint(
        self,
        painter: "QPainter",
        rect: QtCore.QRect,
        mode: QIcon.Mode,
        state: QIcon.State,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qiconengine.html#paint

        **[pure virtual] void QIconEngine::paint(QPainter * painter , const
        QRect & rect , QIcon::Mode mode , QIcon::State state )**

        Uses the given **painter** to paint the icon with the required **mode**
        and **state** into the rectangle **rect**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QQmlParserStatus(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qqmlparserstatus.html

    **Detailed Description**

    QQmlParserStatus provides a mechanism for classes instantiated by a
    **QQmlEngine**  to receive notification at key points in their creation.

    This class is often used for optimization purposes, as it allows you to
    defer an expensive operation until after all the properties have been set on
    an object. For example, QML's **Text**  element uses the parser status to
    defer text layout until all of its properties have been set (we don't want
    to layout when the `text` is assigned, and then relayout when the `font` is
    assigned, and relayout again when the `width` is assigned, and so on).

    Be aware that QQmlParserStatus methods are only called when a class is
    instantiated by a **QQmlEngine** . If you create the same class directly
    from C++, these methods will not be called automatically. To avoid this
    problem, it is recommended that you start deferring operations from
    **classBegin**  instead of from the initial creation of your class. This
    will still prevent multiple revaluations during initial binding assignment
    in QML, but will not defer operations invoked from C++.

    To use QQmlParserStatus, you must inherit both a **QObject** -derived class
    and QQmlParserStatus, and use the **Q_INTERFACES** () macro.

    class MyObject : public **QObject** , public QQmlParserStatus
        {
    Q_OBJECT
            Q_INTERFACES(QQmlParserStatus)

        public:
    MyObject(**QObject**  *parent = 0);
            // ...
            void
    classBegin();
            void componentComplete();
        };
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QQmlParserStatus") -> None:
        ...

    def componentComplete(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlparserstatus.html#componentComplete

        **[pure virtual] void QQmlParserStatus::componentComplete()**

        Invoked after the root component that caused this instantiation has
        completed construction. At this point all static values and binding
        values have been assigned to the class.
        """
        ...

    def classBegin(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlparserstatus.html#classBegin

        **[pure virtual] void QQmlParserStatus::classBegin()**

        Invoked after class creation, but before any properties have been set.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QDnsTextRecord(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdnstextrecord.html

    **Detailed Description**

    When performing a text lookup, zero or more records will be returned. Each
    record is represented by a QDnsTextRecord instance.

    The meaning of the fields is defined in **RFC 1035** .

    **See also** **QDnsLookup** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdnstextrecord.html#QDnsTextRecord

        **QDnsTextRecord::QDnsTextRecord()**

        Constructs an empty text record object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QDnsTextRecord") -> None:
        """
        https://doc.qt.io/qt-6/qdnstextrecord.html#QDnsTextRecord-1

        **QDnsTextRecord::QDnsTextRecord(const QDnsTextRecord & other )**

        Constructs a copy of **other**.
        """
        ...

    def values(self) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qdnstextrecord.html#values

        **QList<QByteArray> QDnsTextRecord::values() const**

        Returns the values for this text record.
        """
        ...

    def timeToLive(self) -> int:
        """
        https://doc.qt.io/qt-6/qdnstextrecord.html#timeToLive

        **quint32 QDnsTextRecord::timeToLive() const**

        Returns the duration in seconds for which this record is valid.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qdnstextrecord.html#name

        **QString QDnsTextRecord::name() const**

        Returns the name for this text record.
        """
        ...

    def swap(self, other: "QDnsTextRecord") -> None:
        """
        https://doc.qt.io/qt-6/qdnstextrecord.html#swap

        **void QDnsTextRecord::swap(QDnsTextRecord & other )**

        Swaps this text record instance with **other**. This function is very
        fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QGuiApplication(QtCore.QCoreApplication):
    """
    https://doc.qt.io/qt-6/qguiapplication.html

    **Detailed Description**

    QGuiApplication contains the main event loop, where all events from the
    window system and other sources are processed and dispatched. It also
    handles the application's initialization and finalization, and provides
    session management. In addition, QGuiApplication handles most of the system-
    wide and application-wide settings.

    For any GUI application using Qt, there is precisely **one** QGuiApplication
    object no matter whether the application has 0, 1, 2 or more windows at any
    given time. For non-GUI Qt applications, use **QCoreApplication**  instead,
    as it does not depend on the Qt GUI module. For **QWidget**  based Qt
    applications, use **QApplication**  instead, as it provides some
    functionality needed for creating **QWidget**  instances.

    The QGuiApplication object is accessible through the **instance** ()
    function, which returns a pointer equivalent to the global **qApp**
    pointer.

    QGuiApplication's main areas of responsibility are:

    * It initializes the application with the user's desktop settings, such as
    **palette** (), **font** () and **styleHints** (). It keeps track of these
    properties in case the user changes the desktop globally, for example,
    through some kind of control panel.
      * It performs event handling, meaning
    that it receives events from the underlying window system and dispatches
    them to the relevant widgets. You can send your own events to windows by
    using **sendEvent** () and **postEvent** ().
      * It parses common command
    line arguments and sets its internal state accordingly. See the
    **constructor documentation**  below for more details.
      * It provides
    localization of strings that are visible to the user via **translate** ().
    * It provides some magical objects like the **clipboard** ().
      * It knows
    about the application's windows. You can ask which window is at a certain
    position using **topLevelAt** (), get a list of **topLevelWindows** (), etc.
    * It manages the application's mouse cursor handling, see
    **setOverrideCursor** ()
      * It provides support for sophisticated **session
    management** . This makes it possible for applications to terminate
    gracefully when the user logs out, to cancel a shutdown process if
    termination isn't possible and even to preserve the entire application's
    state for a future session. See **isSessionRestored** (), **sessionId** ()
    and **commitDataRequest** () and **saveStateRequest** () for details.

    Since the QGuiApplication object does so much initialization, it **must** be
    created before any other objects related to the user interface are created.
    QGuiApplication also deals with common command line arguments. Hence, it is
    usually a good idea to create it **before** any interpretation or
    modification of `argv` is done in the application itself.

    Groups of functions
    System settings**desktopSettingsAware** (),
    **setDesktopSettingsAware** (), **styleHints** (), **palette** (),
    **setPalette** (), **font** (), **setFont** ().
    Event handling**exec** (),
    **processEvents** (), **exit** (), **quit** (). **sendEvent** (),
    **postEvent** (), **sendPostedEvents** (), **removePostedEvents** (),
    **notify** ().
    Windows**allWindows** (), **topLevelWindows** (),
    **focusWindow** (), **clipboard** (), **topLevelAt** ().
    Advanced cursor
    handling**overrideCursor** (), **setOverrideCursor** (),
    **restoreOverrideCursor** ().
    Session management**isSessionRestored** (),
    **sessionId** (), **commitDataRequest** (), **saveStateRequest** ().
    Miscellaneous**startingUp** (), **closingDown** ().

    **See also** **QCoreApplication** , **QAbstractEventDispatcher** , and
    **QEventLoop** .
    """

    def __init__(self, argv: typing.List[str]) -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#QGuiApplication

        **QGuiApplication::QGuiApplication(int & argc , char ** argv )**

        Initializes the window system and constructs an application object with
        **argc** command line arguments in **argv**.

        **Warning:** The data referred to by **argc** and **argv** must stay
        valid for the entire lifetime of the QGuiApplication object. In
        addition, **argc** must be greater than zero and **argv** must contain
        at least one valid character string.

        The global `qApp` pointer refers to this application object. Only one
        application object should be created.

        This application object must be constructed before any **paint devices**
        (including pixmaps, bitmaps etc.).

        **Note:** **argc** and **argv** might be changed as Qt removes command
        line arguments that it recognizes.

        **Supported Command Line Options**

        All Qt programs automatically support a set of command-line options that
        allow modifying the way Qt will interact with the windowing system. Some
        of the options are also accessible via environment variables, which are
        the preferred form if the application can launch GUI sub-processes or
        other applications (environment variables will be inherited by child
        processes). When in doubt, use the environment variables.

        The options currently supported are the following:

        * `-platform` ****platformName** [:options]**, specifies the **Qt
        Platform Abstraction**  (QPA) plugin.

        Overrides the `QT_QPA_PLATFORM`
        environment variable.

          * `-platformpluginpath` **path** , specifies
        the path to platform plugins.

        Overrides the
        `QT_QPA_PLATFORM_PLUGIN_PATH` environment variable.

          *
        `-platformtheme` **platformTheme** , specifies the platform theme.
        Overrides the `QT_QPA_PLATFORMTHEME` environment variable.

          *
        `-plugin` **plugin** , specifies additional plugins to load. The
        argument may appear multiple times.

        Concatenated with the plugins in
        the `QT_QPA_GENERIC_PLUGINS` environment variable.

          *
        `-qmljsdebugger=`, activates the QML/JS debugger with a specified port.
        The value must be of format `port:1234` **[,block]** , where **block**
        is optional and will make the application wait until a debugger connects
        to it.
          * `-qwindowgeometry` **geometry** , specifies window geometry
        for the main window using the X11-syntax. For example: `-qwindowgeometry
        100x100+50+50`
          * `-qwindowicon`, sets the default window icon
          *
        `-qwindowtitle`, sets the title of the first window
          * `-reverse`, sets
        the application's layout direction to **Qt::RightToLeft** . This option
        is intended to aid debugging and should not be used in production. The
        default value is automatically detected from the user's locale (see also
        **QLocale::textDirection** ()).
          * `-session` **session** , restores
        the application from an earlier **session** .

        The following standard command line options are available for X11:

        * `-display` **hostname:screen_number** , switches displays on X11.
        Overrides the `DISPLAY` environment variable.

          * `-geometry`
        **geometry** , same as `-qwindowgeometry`.

        **Platform-Specific Arguments**

        You can specify platform-specific arguments for the `-platform` option.
        Place them after the platform plugin name following a colon as a comma-
        separated list. For example, `-platform
        windows:dialogs=xp,fontengine=freetype`.

        The following parameters are available for `-platform windows`:

        * `altgr`, detect the key `AltGr` found on some keyboards as
        **Qt::GroupSwitchModifier**  (since Qt 5.12).
          * `darkmode=[1|2]`
        controls how Qt responds to the activation of the **Dark Mode for
        applications** introduced in Windows 10 1903 (since Qt 5.15).

        A value
        of 1 causes Qt to switch the window borders to black when **Dark Mode
        for applications** is activated and no High Contrast Theme is in use.
        This is intended for applications that implement their own theming.

        A
        value of 2 will in addition cause the Windows Vista style to be
        deactivated and switch to the Windows style using a simplified palette
        in dark mode. This is currently experimental pending the introduction of
        new style that properly adapts to dark mode.

          * `dialogs=[xp|none]`,
        `xp` uses XP-style native dialogs and `none` disables them.
          *
        `fontengine=freetype`, uses the FreeType font engine.
          *
        `fontengine=directwrite`, uses the experimental DirectWrite font
        database and defaults to using the DirectWrite font engine (which is
        otherwise only used for some font types or font properties.) This
        affects font selection and aims to provide font naming more consistent
        with other platforms, but does not support all font formats, such as
        Postscript Type-1 or Microsoft FNT fonts.
          * `menus=[native|none]`,
        controls the use of native menus.

        Native menus are implemented using
        Win32 API and are simpler than **QMenu** -based menus in for example
        that they do allow for placing widgets on them or changing properties
        like fonts and do not provide hover signals. They are mainly intended
        for Qt Quick. By default, they will be used if the application is not an
        instance of **QApplication**  or for Qt Quick Controls 2 applications
        (since Qt 5.10).

          * `nocolorfonts` Turn off DirectWrite Color fonts
        (since Qt 5.8).
          * `nodirectwrite` Turn off DirectWrite fonts (since Qt
        5.8).
          * `nomousefromtouch` Ignores mouse events synthesized from touch
        events by the operating system.
          * `nowmpointer` Switches from Pointer
        Input Messages handling to legacy mouse handling (since Qt 5.12).
          *
        `reverse` Activates Right-to-left mode (experimental). Windows title
        bars will be shown accordingly in Right-to-left locales (since Qt 5.13).
        * `tabletabsoluterange=<value>` Sets a value for mouse mode detection of
        WinTab tablets (Legacy, since Qt 5.3).

        The following parameter is available for `-platform cocoa` (on macOS):

        * `fontengine=freetype`, uses the FreeType font engine.

        For more information about the platform-specific arguments available for
        embedded Linux platforms, see **Qt for Embedded Linux** .

        **See also** **arguments** () and **QGuiApplication::platformName** .
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#event

        **[override virtual protected] bool QGuiApplication::event(QEvent * e
        )**

        Reimplements: **QCoreApplication::event** (QEvent *e).
        """
        ...

    @staticmethod
    def highDpiScaleFactorRoundingPolicy() -> QtCore.Qt.HighDpiScaleFactorRoundingPolicy:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#highDpiScaleFactorRoundingPo
        licy

        **[static, since 5.14] Qt::HighDpiScaleFactorRoundingPolicy
        QGuiApplication::highDpiScaleFactorRoundingPolicy()**

        Returns the high-DPI scale factor rounding policy.

        This function was introduced in Qt 5.14.

        **See also** **setHighDpiScaleFactorRoundingPolicy** ().
        """
        ...

    @staticmethod
    def setHighDpiScaleFactorRoundingPolicy(
        policy: QtCore.Qt.HighDpiScaleFactorRoundingPolicy,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#setHighDpiScaleFactorRoundin
        gPolicy

        **[static, since 5.14] void QGuiApplication::setHighDpiScaleFactorRoundi
        ngPolicy(Qt::HighDpiScaleFactorRoundingPolicy policy )**

        Sets the high-DPI scale factor rounding policy for the application. The
        **policy** decides how non-integer scale factors (such as Windows 150%)
        are handled.

        The two principal options are whether fractional scale factors should be
        rounded to an integer or not. Keeping the scale factor as-is will make
        the user interface size match the OS setting exactly, but may cause
        painting errors, for example with the Windows style.

        If rounding is wanted, then which type of rounding should be decided
        next. Mathematically correct rounding is supported but may not give the
        best visual results: Consider if you want to render 1.5x as 1x ("small
        UI") or as 2x ("large UI"). See the
        **Qt::HighDpiScaleFactorRoundingPolicy**  enum for a complete list of
        all options.

        This function must be called before creating the application object. The
        **QGuiApplication::highDpiScaleFactorRoundingPolicy** () accessor will
        reflect the environment, if set.

        The default value is
        **Qt::HighDpiScaleFactorRoundingPolicy::PassThrough** .

        This function was introduced in Qt 5.14.

        **See also** **highDpiScaleFactorRoundingPolicy** ().
        """
        ...

    @staticmethod
    def screenAt(point: QtCore.QPoint) -> "QScreen":
        """
        https://doc.qt.io/qt-6/qguiapplication.html#screenAt

        **[static, since 5.10] QScreen *QGuiApplication::screenAt(const QPoint &
        point )**

        Returns the screen at **point** , or `nullptr` if outside of any screen.

        The **point** is in relation to the virtualGeometry() of each set of
        virtual siblings. If the point maps to more than one set of virtual
        siblings the first match is returned. If you wish to search only the
        virtual desktop siblings of a known screen (for example siblings of the
        screen of your application window `QWidget::windowHandle()->screen()`),
        use **QScreen::virtualSiblingAt** ().

        This function was introduced in Qt 5.10.
        """
        ...

    @staticmethod
    def desktopFileName() -> str:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#desktopFileName-prop

        **[since 5.7] desktopFileName : QString**

        This property holds the base name of the desktop entry for this
        application

        This is the file name, without the full path, of the desktop entry that
        represents this application according to the freedesktop desktop entry
        specification.

        This property gives a precise indication of what desktop entry
        represents the application and it is needed by the windowing system to
        retrieve such information without resorting to imprecise heuristics.

        The latest version of the freedesktop desktop entry specification can be
        obtained **here** .

        This property was introduced in Qt 5.7.

        **Access functions:**

        QString **desktopFileName** ()
        void **setDesktopFileName** (const
        QString & **name** )
        """
        ...

    @staticmethod
    def setDesktopFileName(name: str) -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#desktopFileName-prop

        **[since 5.7] desktopFileName : QString**

        This property holds the base name of the desktop entry for this
        application

        This is the file name, without the full path, of the desktop entry that
        represents this application according to the freedesktop desktop entry
        specification.

        This property gives a precise indication of what desktop entry
        represents the application and it is needed by the windowing system to
        retrieve such information without resorting to imprecise heuristics.

        The latest version of the freedesktop desktop entry specification can be
        obtained **here** .

        This property was introduced in Qt 5.7.

        **Access functions:**

        QString **desktopFileName** ()
        void **setDesktopFileName** (const
        QString & **name** )
        """
        ...

    @staticmethod
    def windowIcon() -> "QIcon":
        """
        https://doc.qt.io/qt-6/qguiapplication.html#windowIcon-prop

        **windowIcon : QIcon**

        This property holds the default window icon

        **Access functions:**

        QIcon **windowIcon** ()
        void **setWindowIcon** (const QIcon & **icon**
        )

        **See also** **QWindow::setIcon** () and **Setting the Application
        Icon** .

        **Member Function Documentation**
        """
        ...

    @staticmethod
    def setWindowIcon(icon: "QIcon") -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#windowIcon-prop

        **windowIcon : QIcon**

        This property holds the default window icon

        **Access functions:**

        QIcon **windowIcon** ()
        void **setWindowIcon** (const QIcon & **icon**
        )

        **See also** **QWindow::setIcon** () and **Setting the Application
        Icon** .

        **Member Function Documentation**
        """
        ...

    @staticmethod
    def sync() -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#sync

        **[static, since 5.2] void QGuiApplication::sync()**

        Function that can be used to sync Qt state with the Window Systems
        state.

        This function will first empty Qts events by calling
        **QCoreApplication::processEvents** (), then the platform plugin will
        sync up with the windowsystem, and finally Qts events will be delived by
        another call to **QCoreApplication::processEvents** ();

        This function is timeconsuming and its use is discouraged.

        This function was introduced in Qt 5.2.
        """
        ...

    @staticmethod
    def applicationState() -> QtCore.Qt.ApplicationState:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#applicationState

        **[static, since 5.2] Qt::ApplicationState
        QGuiApplication::applicationState()**

        Returns the current state of the application.

        You can react to application state changes to perform actions such as
        stopping/resuming CPU-intensive tasks, freeing/loading resources or
        saving/restoring application data.

        This function was introduced in Qt 5.2.
        """
        ...

    def isSavingSession(self) -> bool:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#isSavingSession

        **[since 5.0] bool QGuiApplication::isSavingSession() const**

        Returns `true` if the application is currently saving the **session** ;
        otherwise returns `false`.

        This is `true` when **commitDataRequest** () and **saveStateRequest** ()
        are emitted, but also when the windows are closed afterwards by session
        management.

        This function was introduced in Qt 5.0.

        **See also** **sessionId** (), **commitDataRequest** (), and
        **saveStateRequest** ().
        """
        ...

    def sessionKey(self) -> str:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#sessionKey

        **QString QGuiApplication::sessionKey() const**

        Returns the session key in the current **session** .

        If the application has been restored from an earlier session, this key
        is the same as it was when the previous session ended.

        The session key changes every time the session is saved. If the shutdown
        process is cancelled, another session key will be used when shutting
        down again.

        **See also** **isSessionRestored** (), **sessionId** (),
        **commitDataRequest** (), and **saveStateRequest** ().
        """
        ...

    def sessionId(self) -> str:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#sessionId

        **QString QGuiApplication::sessionId() const**

        Returns the current **session's**  identifier.

        If the application has been restored from an earlier session, this
        identifier is the same as it was in that previous session. The session
        identifier is guaranteed to be unique both for different applications
        and for different instances of the same application.

        **See also** **isSessionRestored** (), **sessionKey** (),
        **commitDataRequest** (), and **saveStateRequest** ().
        """
        ...

    def isSessionRestored(self) -> bool:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#isSessionRestored

        **bool QGuiApplication::isSessionRestored() const**

        Returns `true` if the application has been restored from an earlier
        **session** ; otherwise returns `false`.

        **See also** **sessionId** (), **commitDataRequest** (), and
        **saveStateRequest** ().
        """
        ...

    def devicePixelRatio(self) -> float:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#devicePixelRatio

        **qreal QGuiApplication::devicePixelRatio() const**

        Returns the highest screen device pixel ratio found on the system. This
        is the ratio between physical pixels and device-independent pixels.

        Use this function only when you don't know which window you are
        targeting. If you do know the target window, use
        **QWindow::devicePixelRatio** () instead.

        **See also** **QWindow::devicePixelRatio** ().
        """
        ...

    @staticmethod
    def inputMethod() -> "QInputMethod":
        """
        https://doc.qt.io/qt-6/qguiapplication.html#inputMethod

        **[static] QInputMethod *QGuiApplication::inputMethod()**

        returns the input method.

        The input method returns properties about the state and position of the
        virtual keyboard. It also provides information about the position of the
        current focused input element.

        **See also** **QInputMethod** .
        """
        ...

    @staticmethod
    def styleHints() -> "QStyleHints":
        """
        https://doc.qt.io/qt-6/qguiapplication.html#styleHints

        **[static] QStyleHints *QGuiApplication::styleHints()**

        Returns the application's style hints.

        The style hints encapsulate a set of platform dependent properties such
        as double click intervals, full width selection and others.

        The hints can be used to integrate tighter with the underlying platform.

        **See also** **QStyleHints** .
        """
        ...

    @staticmethod
    def modalWindow() -> "QWindow":
        """
        https://doc.qt.io/qt-6/qguiapplication.html#modalWindow

        **[static] QWindow *QGuiApplication::modalWindow()**

        Returns the most recently shown modal window. If no modal windows are
        visible, this function returns zero.

        A modal window is a window which has its **modality**  property set to
        **Qt::WindowModal**  or **Qt::ApplicationModal** . A modal window must
        be closed before the user can continue with other parts of the program.

        Modal window are organized in a stack. This function returns the modal
        window at the top of the stack.

        **See also** **Qt::WindowModality**  and **QWindow::setModality** ().
        """
        ...

    @staticmethod
    def applicationDisplayName() -> str:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#applicationDisplayName-prop

        **[since 5.0] applicationDisplayName : QString**

        This property holds the user-visible name of this application

        This name is shown to the user, for instance in window titles. It can be
        translated, if necessary.

        If not set, the application display name defaults to the application
        name.

        This property was introduced in Qt 5.0.

        **Access functions:**

        QString **applicationDisplayName** ()
        void
        **setApplicationDisplayName** (const QString & **name** )

        **Notifier signal:**

        void **applicationDisplayNameChanged** ()

        **See also** **applicationName** .
        """
        ...

    @staticmethod
    def setApplicationDisplayName(name: str) -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#applicationDisplayName-prop

        **[since 5.0] applicationDisplayName : QString**

        This property holds the user-visible name of this application

        This name is shown to the user, for instance in window titles. It can be
        translated, if necessary.

        If not set, the application display name defaults to the application
        name.

        This property was introduced in Qt 5.0.

        **Access functions:**

        QString **applicationDisplayName** ()
        void
        **setApplicationDisplayName** (const QString & **name** )

        **Notifier signal:**

        void **applicationDisplayNameChanged** ()

        **See also** **applicationName** .
        """
        ...

    def notify(self, a0: QtCore.QObject, a1: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#notify

        **[override virtual] bool QGuiApplication::notify(QObject * object ,
        QEvent * event )**

        Reimplements: **QCoreApplication::notify** (QObject *receiver, QEvent
        *event).
        """
        ...

    @staticmethod
    def exec() -> int:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#exec

        **[static] int QGuiApplication::exec()**

        Enters the main event loop and waits until **exit** () is called, and
        then returns the value that was set to **exit** () (which is 0 if
        **exit** () is called via **quit** ()).

        It is necessary to call this function to start event handling. The main
        event loop receives events from the window system and dispatches these
        to the application widgets.

        Generally, no user interaction can take place before calling exec().

        To make your application perform idle processing, e.g., executing a
        special function whenever there are no pending events, use a **QTimer**
        with 0 timeout. More advanced idle processing schemes can be achieved
        using **processEvents** ().

        We recommend that you connect clean-up code to the **aboutToQuit** ()
        signal, instead of putting it in your application's `main()` function.
        This is because, on some platforms, the **QApplication::exec** () call
        may not return.

        **See also** **quitOnLastWindowClosed** , **quit** (), **exit** (),
        **processEvents** (), and **QCoreApplication::exec** ().
        """
        ...

    @staticmethod
    def quitOnLastWindowClosed() -> bool:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#quitOnLastWindowClosed-prop

        **quitOnLastWindowClosed : bool**

        This property holds whether the application implicitly quits when the
        last window is closed.

        The default is `true`.

        If this property is `true`, the applications quits when the last visible
        primary window (i.e. window with no parent) is closed.

        **Access functions:**

        bool **quitOnLastWindowClosed** ()
        void **setQuitOnLastWindowClosed**
        (bool **quit** )

        **See also** **quit** () and **QWindow::close** ().
        """
        ...

    @staticmethod
    def setQuitOnLastWindowClosed(quit: bool) -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#quitOnLastWindowClosed-prop

        **quitOnLastWindowClosed : bool**

        This property holds whether the application implicitly quits when the
        last window is closed.

        The default is `true`.

        If this property is `true`, the applications quits when the last visible
        primary window (i.e. window with no parent) is closed.

        **Access functions:**

        bool **quitOnLastWindowClosed** ()
        void **setQuitOnLastWindowClosed**
        (bool **quit** )

        **See also** **quit** () and **QWindow::close** ().
        """
        ...

    @staticmethod
    def desktopSettingsAware() -> bool:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#desktopSettingsAware

        **[static] bool QGuiApplication::desktopSettingsAware()**

        Returns `true` if Qt is set to use the system's standard colors, fonts,
        etc.; otherwise returns `false`. The default is `true`.

        **See also** **setDesktopSettingsAware** ().
        """
        ...

    @staticmethod
    def setDesktopSettingsAware(on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#setDesktopSettingsAware

        **[static] void QGuiApplication::setDesktopSettingsAware(bool on )**

        Sets whether Qt should use the system's standard colors, fonts, etc., to
        **on**. By default, this is `true`.

        This function must be called before creating the **QGuiApplication**
        object, like this:

        int main(int argc, char *argv[])
            {
                **QApplication**
        ::setDesktopSettingsAware(false);
                **QApplication**  app(argc,
        argv);
                // ...
                return app.exec();
            }

        **See also** **desktopSettingsAware** ().
        """
        ...

    @staticmethod
    def isLeftToRight() -> bool:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#isLeftToRight

        **[static] bool QGuiApplication::isLeftToRight()**

        Returns `true` if the application's layout direction is
        **Qt::LeftToRight** ; otherwise returns `false`.

        **See also** **layoutDirection** () and **isRightToLeft** ().
        """
        ...

    @staticmethod
    def isRightToLeft() -> bool:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#isRightToLeft

        **[static] bool QGuiApplication::isRightToLeft()**

        Returns `true` if the application's layout direction is
        **Qt::RightToLeft** ; otherwise returns `false`.

        **See also** **layoutDirection** () and **isLeftToRight** ().
        """
        ...

    @staticmethod
    def layoutDirection() -> QtCore.Qt.LayoutDirection:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#layoutDirection-prop

        **layoutDirection : Qt::LayoutDirection**

        This property holds the default layout direction for this application

        On system start-up, the default layout direction depends on the
        application's language.

        The notifier signal was introduced in Qt 5.4.

        **Access functions:**

        Qt::LayoutDirection **layoutDirection** ()
        void **setLayoutDirection**
        (Qt::LayoutDirection **direction** )

        **Notifier signal:**

        void **layoutDirectionChanged** (Qt::LayoutDirection **direction** )

        **See also** **QWidget::layoutDirection** , **isLeftToRight** (), and
        **isRightToLeft** ().
        """
        ...

    @staticmethod
    def setLayoutDirection(direction: QtCore.Qt.LayoutDirection) -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#layoutDirection-prop

        **layoutDirection : Qt::LayoutDirection**

        This property holds the default layout direction for this application

        On system start-up, the default layout direction depends on the
        application's language.

        The notifier signal was introduced in Qt 5.4.

        **Access functions:**

        Qt::LayoutDirection **layoutDirection** ()
        void **setLayoutDirection**
        (Qt::LayoutDirection **direction** )

        **Notifier signal:**

        void **layoutDirectionChanged** (Qt::LayoutDirection **direction** )

        **See also** **QWidget::layoutDirection** , **isLeftToRight** (), and
        **isRightToLeft** ().
        """
        ...

    @staticmethod
    def mouseButtons() -> QtCore.Qt.MouseButton:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#mouseButtons

        **[static] Qt::MouseButtons QGuiApplication::mouseButtons()**

        Returns the current state of the buttons on the mouse. The current state
        is updated synchronously as the event queue is emptied of events that
        will spontaneously change the mouse state (**QEvent::MouseButtonPress**
        and **QEvent::MouseButtonRelease**  events).

        It should be noted this may not reflect the actual buttons held on the
        input device at the time of calling but rather the mouse buttons as last
        reported in one of the above events. If no mouse buttons are being held
        **Qt::NoButton**  is returned.

        **See also** **keyboardModifiers** ().
        """
        ...

    @staticmethod
    def queryKeyboardModifiers() -> QtCore.Qt.KeyboardModifier:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#queryKeyboardModifiers

        **[static] Qt::KeyboardModifiers
        QGuiApplication::queryKeyboardModifiers()**

        Queries and returns the state of the modifier keys on the keyboard.
        Unlike **keyboardModifiers** , this method returns the actual keys held
        on the input device at the time of calling the method.

        It does not rely on the keypress events having been received by this
        process, which makes it possible to check the modifiers while moving a
        window, for instance. Note that in most cases, you should use
        **keyboardModifiers** (), which is faster and more accurate since it
        contains the state of the modifiers as they were when the currently
        processed event was received.

        **See also** **keyboardModifiers** ().
        """
        ...

    @staticmethod
    def keyboardModifiers() -> QtCore.Qt.KeyboardModifier:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#keyboardModifiers

        **[static] Qt::KeyboardModifiers QGuiApplication::keyboardModifiers()**

        Returns the current state of the modifier keys on the keyboard. The
        current state is updated synchronously as the event queue is emptied of
        events that will spontaneously change the keyboard state
        (**QEvent::KeyPress**  and **QEvent::KeyRelease**  events).

        It should be noted this may not reflect the actual keys held on the
        input device at the time of calling but rather the modifiers as last
        reported in one of the above events. If no keys are being held
        **Qt::NoModifier**  is returned.

        **See also** **mouseButtons** () and **queryKeyboardModifiers** ().
        """
        ...

    @staticmethod
    def setPalette(pal: "QPalette") -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#setPalette

        **[static] void QGuiApplication::setPalette(const QPalette & pal )**

        Changes the application palette to **pal**.

        The color roles from this palette are combined with the system's
        platform theme to form the application's final palette.

        **See also** **palette** ().
        """
        ...

    @staticmethod
    def palette() -> "QPalette":
        """
        https://doc.qt.io/qt-6/qguiapplication.html#palette

        **[static] QPalette QGuiApplication::palette()**

        Returns the current application palette.

        Roles that have not been explicitly set will reflect the system's
        platform theme.

        **See also** **setPalette** ().
        """
        ...

    @staticmethod
    def clipboard() -> QClipboard:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#clipboard

        **[static] QClipboard *QGuiApplication::clipboard()**

        Returns the object for interacting with the clipboard.
        """
        ...

    @staticmethod
    def setFont(a0: QFont) -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#setFont

        **[static] void QGuiApplication::setFont(const QFont & font )**

        Changes the default application font to **font**.

        **See also** **font** ().
        """
        ...

    @staticmethod
    def font() -> QFont:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#font

        **[static] QFont QGuiApplication::font()**

        Returns the default application font.

        **See also** **setFont** ().
        """
        ...

    @staticmethod
    def restoreOverrideCursor() -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#restoreOverrideCursor

        **[static] void QGuiApplication::restoreOverrideCursor()**

        Undoes the last **setOverrideCursor** ().

        If **setOverrideCursor** () has been called twice, calling
        restoreOverrideCursor() will activate the first cursor set. Calling this
        function a second time restores the original widgets' cursors.

        **See also** **setOverrideCursor** () and **overrideCursor** ().
        """
        ...

    @staticmethod
    def changeOverrideCursor(a0: typing.Union[QCursor, QtCore.Qt.CursorShape]) -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#changeOverrideCursor

        **[static] void QGuiApplication::changeOverrideCursor(const QCursor &
        cursor )**

        Changes the currently active application override cursor to **cursor**.

        This function has no effect if **setOverrideCursor** () was not called.

        **See also** **setOverrideCursor** (), **overrideCursor** (),
        **restoreOverrideCursor** (), and **QWidget::setCursor** ().
        """
        ...

    @staticmethod
    def setOverrideCursor(a0: typing.Union[QCursor, QtCore.Qt.CursorShape]) -> None:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#setOverrideCursor

        **[static] void QGuiApplication::setOverrideCursor(const QCursor &
        cursor )**

        Sets the application override cursor to **cursor**.

        Application override cursors are intended for showing the user that the
        application is in a special state, for example during an operation that
        might take some time.

        This cursor will be displayed in all the application's widgets until
        **restoreOverrideCursor** () or another setOverrideCursor() is called.

        Application cursors are stored on an internal stack. setOverrideCursor()
        pushes the cursor onto the stack, and **restoreOverrideCursor** () pops
        the active cursor off the stack. **changeOverrideCursor** () changes the
        currently active application override cursor.

        Every setOverrideCursor() must eventually be followed by a corresponding
        **restoreOverrideCursor** (), otherwise the stack will never be emptied.

        Example:

        **QGuiApplication** ::setOverrideCursor(**QCursor** (Qt::WaitCursor));
        calculateHugeMandelbrot();              // lunch time...
        **QGuiApplication** ::restoreOverrideCursor();

        **See also** **overrideCursor** (), **restoreOverrideCursor** (),
        **changeOverrideCursor** (), and **QWidget::setCursor** ().
        """
        ...

    @staticmethod
    def overrideCursor() -> QCursor:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#overrideCursor

        **[static] QCursor *QGuiApplication::overrideCursor()**

        Returns the active application override cursor.

        This function returns `nullptr` if no application cursor has been
        defined (i.e. the internal cursor stack is empty).

        **See also** **setOverrideCursor** () and **restoreOverrideCursor** ().
        """
        ...

    @staticmethod
    def screens() -> typing.List["QScreen"]:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#screens

        **[static] QList<QScreen *> QGuiApplication::screens()**

        Returns a list of all the screens associated with the windowing system
        the application is connected to.
        """
        ...

    @staticmethod
    def primaryScreen() -> "QScreen":
        """
        https://doc.qt.io/qt-6/qguiapplication.html#primaryScreen-prop

        **[read-only] primaryScreen : QScreen* const**

        This property holds the primary (or default) screen of the application.

        This will be the screen where QWindows are initially shown, unless
        otherwise specified.

        The primaryScreenChanged signal was introduced in Qt 5.6.

        **Access functions:**

        QScreen * **primaryScreen** ()

        **Notifier signal:**

        void **primaryScreenChanged** (QScreen * **screen** )

        **See also** **screens** ().
        """
        ...

    @staticmethod
    def focusObject() -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#focusObject

        **[static] QObject *QGuiApplication::focusObject()**

        Returns the **QObject**  in currently active window that will be final
        receiver of events tied to focus, such as key events.
        """
        ...

    @staticmethod
    def focusWindow() -> "QWindow":
        """
        https://doc.qt.io/qt-6/qguiapplication.html#focusWindow

        **[static] QWindow *QGuiApplication::focusWindow()**

        Returns the **QWindow**  that receives events tied to focus, such as key
        events.
        """
        ...

    @staticmethod
    def platformName() -> str:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#platformName-prop

        **[read-only] platformName : const QString**

        This property holds the name of the underlying platform plugin.

        The QPA platform plugins are located in `qtbase\\src\\plugins\\platforms`.
        At the time of writing, the following platform plugin names are
        supported:

        * `android`
          * `cocoa` is a platform plugin for macOS.
          * `directfb`
        * `eglfs` is a platform plugin for running Qt5 applications on top of
        EGL and OpenGL ES 2.0 without an actual windowing system (like X11 or
        Wayland). For more information, see **EGLFS** .
          * `ios` (also used for
        tvOS)
          * `linuxfb` writes directly to the framebuffer. For more
        information, see **LinuxFB** .
          * `minimal` is provided as an examples
        for developers who want to write their own platform plugins. However,
        you can use the plugin to run GUI applications in environments without a
        GUI, such as servers.
          * `minimalegl` is an example plugin.
          *
        `offscreen`
          * `qnx`
          * `windows`
          * `wayland` is a platform plugin
        for modern Linux desktops and some embedded systems.
          * `xcb` is the
        X11 plugin used on regular desktop Linux platforms.

        For more information about the platform plugins for embedded Linux
        devices, see **Qt for Embedded Linux** .

        **Access functions:**

        QString **platformName** ()
        """
        ...

    @staticmethod
    def topLevelAt(pos: QtCore.QPoint) -> "QWindow":
        """
        https://doc.qt.io/qt-6/qguiapplication.html#topLevelAt

        **[static] QWindow *QGuiApplication::topLevelAt(const QPoint & pos )**

        Returns the top level window at the given position **pos** , if any.
        """
        ...

    @staticmethod
    def topLevelWindows() -> typing.List["QWindow"]:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#topLevelWindows

        **[static] QWindowList QGuiApplication::topLevelWindows()**

        Returns a list of the top-level windows in the application.

        **See also** **allWindows** ().
        """
        ...

    @staticmethod
    def allWindows() -> typing.List["QWindow"]:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#allWindows

        **[static] QWindowList QGuiApplication::allWindows()**

        Returns a list of all the windows in the application.

        The list is empty if there are no windows.

        **See also** **topLevelWindows** ().
        """
        ...

    @property
    def applicationDisplayNameChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def applicationStateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#applicationStateChanged

        **[signal, since 5.2] void
        QGuiApplication::applicationStateChanged(Qt::ApplicationState state )**

        This signal is emitted when the **state** of the application changes.

        This function was introduced in Qt 5.2.

        **See also** **applicationState** ().
        """
        ...

    @property
    def commitDataRequest(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#commitDataRequest

        **[signal] void QGuiApplication::commitDataRequest(QSessionManager &
        manager )**

        This signal deals with **session management** . It is emitted when the
        **QSessionManager**  wants the application to commit all its data.

        Usually this means saving all open files, after getting permission from
        the user. Furthermore you may want to provide a means by which the user
        can cancel the shutdown.

        You should not exit the application within this signal. Instead, the
        session manager may or may not do this afterwards, depending on the
        context.

        **Warning:** Within this signal, no user interaction is possible,
        **unless** you ask the **manager** for explicit permission. See
        **QSessionManager::allowsInteraction** () and
        **QSessionManager::allowsErrorInteraction** () for details and example
        usage.

        **Note:** You should use **Qt::DirectConnection**  when connecting to
        this signal.

        **See also** **isSessionRestored** (), **sessionId** (),
        **saveStateRequest** (), and **Session Management** .
        """
        ...

    @property
    def focusObjectChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#focusObjectChanged

        **[signal] void QGuiApplication::focusObjectChanged(QObject *
        focusObject )**

        This signal is emitted when final receiver of events tied to focus is
        changed. **focusObject** is the new receiver.

        **See also** **focusObject** ().
        """
        ...

    @property
    def focusWindowChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#focusWindowChanged

        **[signal] void QGuiApplication::focusWindowChanged(QWindow *
        focusWindow )**

        This signal is emitted when the focused window changes. **focusWindow**
        is the new focused window.

        **See also** **focusWindow** ().
        """
        ...

    @property
    def fontDatabaseChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#fontDatabaseChanged

        **[signal] void QGuiApplication::fontDatabaseChanged()**

        This signal is emitted when application fonts are loaded or removed.

        **See also** **QFontDatabase::addApplicationFont** (),
        **QFontDatabase::addApplicationFontFromData** (),
        **QFontDatabase::removeAllApplicationFonts** (), and
        **QFontDatabase::removeApplicationFont** ().
        """
        ...

    @property
    def lastWindowClosed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#lastWindowClosed

        **[signal] void QGuiApplication::lastWindowClosed()**

        This signal is emitted from **exec** () when the last visible primary
        window (i.e. window with no parent) is closed.

        By default, **QGuiApplication**  quits after this signal is emitted.
        This feature can be turned off by setting **quitOnLastWindowClosed**  to
        `false`.

        **See also** **QWindow::close** () and **QWindow::isTopLevel** ().
        """
        ...

    @property
    def layoutDirectionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def primaryScreenChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def saveStateRequest(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#saveStateRequest

        **[signal] void QGuiApplication::saveStateRequest(QSessionManager &
        manager )**

        This signal deals with **session management** . It is invoked when the
        **session manager**  wants the application to preserve its state for a
        future session.

        For example, a text editor would create a temporary file that includes
        the current contents of its edit buffers, the location of the cursor and
        other aspects of the current editing session.

        You should never exit the application within this signal. Instead, the
        session manager may or may not do this afterwards, depending on the
        context. Furthermore, most session managers will very likely request a
        saved state immediately after the application has been started. This
        permits the session manager to learn about the application's restart
        policy.

        **Warning:** Within this signal, no user interaction is possible,
        **unless** you ask the **manager** for explicit permission. See
        **QSessionManager::allowsInteraction** () and
        **QSessionManager::allowsErrorInteraction** () for details.

        **Note:** You should use **Qt::DirectConnection**  when connecting to
        this signal.

        **See also** **isSessionRestored** (), **sessionId** (),
        **commitDataRequest** (), and **Session Management** .
        """
        ...

    @property
    def screenAdded(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#screenAdded

        **[signal] void QGuiApplication::screenAdded(QScreen * screen )**

        This signal is emitted whenever a new screen **screen** has been added
        to the system.

        **See also** **screens** (), **primaryScreen** , and **screenRemoved**
        ().
        """
        ...

    @property
    def screenRemoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qguiapplication.html#screenRemoved

        **[signal, since 5.4] void QGuiApplication::screenRemoved(QScreen *
        screen )**

        This signal is emitted whenever a **screen** is removed from the system.
        It provides an opportunity to manage the windows on the screen before Qt
        falls back to moving them to the primary screen.

        This function was introduced in Qt 5.4.

        **See also** **screens** (), **screenAdded** (), **QObject::destroyed**
        (), and **QWindow::setScreen** ().
        """
        ...
